PRINT N'Iniciando recompilación de la tabla [dbo].[BatchSchedule]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_BatchSchedule] (
    [VCC]                  VARCHAR (50)  NOT NULL,
    [Id]                   VARCHAR (50)  NOT NULL,
    [BatchType]            VARCHAR (50)  NOT NULL,
    [Frequency]            VARCHAR (50)  NULL,
    [Weekday]              INT           NULL,
    [Monthday]             INT           NULL,
    [DaysInterval]         INT           NULL,
    [HoursInterval]        INT           NULL,
    [StartDate]            DATETIME      NULL,
    [EndDate]              DATETIME      NULL,
    [FirstExecutionDate]   DATETIME      NULL,
    [LastExecutionDate]    DATETIME      NULL,
    [FinalExecutionDate]   DATETIME      NULL,
    [ExecutionDelay]       INT           CONSTRAINT [DF_BatchSchedule_ExecutionDelay] DEFAULT ((0)) NULL,
    [BatchData]            VARCHAR (MAX) NULL,
    [ProcessFiltersId]     VARCHAR (50)  NULL,
    [Status]               VARCHAR (50)  NULL,
    [CreatedDate]          DATETIME      NULL,
    [CreatedByUserId]      VARCHAR (50)  NULL,
    [LastModifiedDate]     DATETIME      NULL,
    [LastModifiedByUserId] VARCHAR (50)  NULL,
    [TimeStamp]            DATETIME      NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_BatchSchedule1] PRIMARY KEY CLUSTERED ([VCC] ASC, [Id] ASC, [BatchType] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[BatchSchedule])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_BatchSchedule] ([VCC], [Id], [BatchType], [Frequency], [Weekday], [Monthday], [DaysInterval], [HoursInterval], [StartDate], [EndDate], [FirstExecutionDate], [LastExecutionDate], [FinalExecutionDate], [BatchData], [ProcessFiltersId], [Status], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp])
        SELECT   [VCC],
                 [Id],
                 [BatchType],
                 [Frequency],
                 [Weekday],
                 [Monthday],
                 [DaysInterval],
                 [HoursInterval],
                 [StartDate],
                 [EndDate],
                 [FirstExecutionDate],
                 [LastExecutionDate],
                 [FinalExecutionDate],
                 [BatchData],
                 [ProcessFiltersId],
                 [Status],
                 [CreatedDate],
                 [CreatedByUserId],
                 [LastModifiedDate],
                 [LastModifiedByUserId],
                 [TimeStamp]
        FROM     [dbo].[BatchSchedule]
        ORDER BY [VCC] ASC, [Id] ASC, [BatchType] ASC;
    END

DROP TABLE [dbo].[BatchSchedule];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_BatchSchedule]', N'BatchSchedule';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_BatchSchedule1]', N'PK_BatchSchedule', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Iniciando recompilación de la tabla [dbo].[BatchScheduleExecution]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_BatchScheduleExecution] (
    [VCC]                  VARCHAR (50) NOT NULL,
    [Id]                   VARCHAR (50) NOT NULL,
    [BatchScheduleId]      VARCHAR (50) NULL,
    [BatchId]              VARCHAR (50) NULL,
    [ProcessId]            VARCHAR (50) NULL,
    [ExecutionDate]        DATETIME     NULL,
    [Order]                INT          NULL,
    [Status]               VARCHAR (50) NULL,
    [CreatedByUserId]      VARCHAR (50) NULL,
    [CreatedDate]          DATETIME     NULL,
    [LastModifiedByUserId] VARCHAR (50) NULL,
    [LastModifiedDate]     DATETIME     NULL,
    [TimeStamp]            DATETIME     NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_BatchScheduleExecution1] PRIMARY KEY CLUSTERED ([VCC] ASC, [Id] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[BatchScheduleExecution])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_BatchScheduleExecution] ([VCC], [Id], [BatchScheduleId], [BatchId], [ExecutionDate], [Order], [Status], [CreatedByUserId], [CreatedDate], [LastModifiedByUserId], [LastModifiedDate], [TimeStamp])
        SELECT   [VCC],
                 [Id],
                 [BatchScheduleId],
                 [BatchId],
                 [ExecutionDate],
                 [Order],
                 [Status],
                 [CreatedByUserId],
                 [CreatedDate],
                 [LastModifiedByUserId],
                 [LastModifiedDate],
                 [TimeStamp]
        FROM     [dbo].[BatchScheduleExecution]
        ORDER BY [VCC] ASC, [Id] ASC;
    END

DROP TABLE [dbo].[BatchScheduleExecution];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_BatchScheduleExecution]', N'BatchScheduleExecution';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_BatchScheduleExecution1]', N'PK_BatchScheduleExecution', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Modificando [dbo].[EvaluationReviewCommitment]...';


GO
ALTER TABLE [dbo].[EvaluationReviewCommitment] ALTER COLUMN [InteractionId] VARCHAR (250) NULL;


GO
PRINT N'Modificando [dbo].[GetBatchScheduleById]...';


GO
ALTER PROCEDURE [dbo].[GetBatchScheduleById] (
	@VCC VARCHAR(50) = NULL, 
	@Id VARCHAR(50) = NULL
	--@Type VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT BS.[Id]								'id',
			BS.[BatchType]						'batchType',
			BS.[Frequency]						'frequency',
			BS.[Weekday]						'weekday',
			BS.[Monthday]						'monthday',
			BS.[DaysInterval]					'daysInterval',
			BS.[HoursInterval]					'hoursInterval',
			BS.[ExecutionDelay]					'executionDelay',
			BS.[StartDate]						'startDate',
			BS.[EndDate]						'endDate',
			BS.[FirstExecutionDate]				'firstExecutionDate',
			BS.[LastExecutionDate]				'lastExecutionDate',
			BS.[FinalExecutionDate]				'finalExecutionDate',
			BS.[Status]							'status',
			BS.[CreatedDate]					'createdDate',
			BS.[CreatedByUserId]				'createdByUserId',
			BS.[LastModifiedDate]				'lastModifiedDate',
			BS.[LastModifiedByUserId]			'lastModifiedByUserId'
		FROM [dbo].[BatchSchedule] BS (NOLOCK)
		WHERE BS.[VCC] = @VCC
			AND BS.[Id] = @Id
			--AND BS.[BatchType] = @Type

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetBatchScheduleExecutionsByBatchType]...';


GO
ALTER PROCEDURE [dbo].[GetBatchScheduleExecutionsByBatchType] (
	@VCC VARCHAR(50) = NULL, 
	@BatchScheduleId VARCHAR(50) = NULL,
	@BatchType VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- SI NO RECIBIMOS EL TIPO, LOS CONSULTAMOS A LA TABLA DE AGENDAS
	IF @BatchType IS NULL
		SELECT @BatchType  = BS.[BatchType] 
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			WHERE BS.[VCC] = @VCC 
				AND BS.[Id] = @BatchScheduleId

	-- EJECUTAMOS LA CONSULTA SEGUN EL TIPO DE BATCH
	IF @BatchType = 'TRANSCRIPTION'
	BEGIN
		-- HACEMOS LA CONSULTA DE BATCHES CORRESPONDIENTES A LA AGENDA
		SELECT BSE.[VCC]										'vcc',
					BSE.[Id]									'id', 
					BSE.[BatchScheduleId]						'batchScheduleId', 
					BSE.[BatchId]								'batchId', 
					BSE.[ExecutionDate]							'executionDate', 
					BS.[ExecutionDelay]							'executionDelay',
					BSE.[Order]									'order', 
					BSE.[Status]								'status', 
					--BSE.[CreatedDate]							'createdDate',
					--BSE.[CreatedByUserId]						'createdByUserId',
					--BSE.[LastModifiedDate]						'lastModifiedDate',
					--BSE.[LastModifiedByUserId]					'lastModifiedByUserId',
					P.[Name]									'name',
					P.[Description]								'description',
					P.[ClientId]								'clientId',
					P.[Percentage]								'percentage',
					P.[StatusDescription]						'statusDescription',
					(
						CASE WHEN P.[Status] IS NULL 
							THEN 'UNKNOWN' 
							ELSE P.[Status] END
					)											'batchStatus',
					P.[StartDate]								'startDate',
					P.[EndDate]									'endDate',
					P.[MinDurationTime]							'minDurationTime',
					P.[MaxDurationTime]							'maxDurationTime',
					P.[Language]								'language',
					P.[Environment]								'environment',
					P.[CreatedDate]								'createdDate',
					P.[CreatedByUserId]							'createdByUserId',
					P.[LastModifiedDate]						'lastModifiedDate',
					P.[LastModifiedByUserId]					'lastModifiedByUserId'
			FROM [dbo].[BatchScheduleExecution] BSE (NOLOCK)
			INNER JOIN [dbo].[BatchSchedule] BS (NOLOCK)
				ON BS.[VCC] = BSE.[VCC]
					AND BS.[Id] = BSE.[BatchScheduleId]
			LEFT JOIN [dbo].[Process] P (NOLOCK)
				ON P.[VCC] = BSE.[VCC]
					AND P.[Name] = BSE.[BatchId]
			WHERE BSE.[VCC] = @VCC
				AND BSE.[BatchScheduleId] = @BatchScheduleId
				AND BSE.[Status] <> 'PENDING'
			ORDER BY BSE.[ExecutionDate] DESC
	END

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetBatchSchedulesSummary]...';


GO
ALTER PROCEDURE [dbo].[GetBatchSchedulesSummary] (
	@VCC VARCHAR(50) = NULL, 
	@SearchCriteria VARCHAR(50) = NULL,
	@SearchExpression VARCHAR(500) = NULL,
	@BatchType VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- CREAMOS UNA TABLA TEMPORAL PARA LA ULTIMA EJECUCION DE CADA AGENDA
	CREATE TABLE #TMP_SCHEDULE_LAST_EXECUTION (
		[VCC] VARCHAR(50),
		[BatchScheduleId] VARCHAR(50),
		[BatchId] VARCHAR(50),
		[LastExecutionDate] DATETIME,
		[Status] VARCHAR(50)
	)
	-- BUSCAMOS LAS ULTIMAS EJECUCIONES DE CADA AGENDA
	;WITH CTE_LAST_VALID_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] DESC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[BatchType] = @BatchType
				AND BS.[Status] IN ('CREATED', 'RUNNING', 'PAUSED', 'FINISHED')
				AND BSE.[Status] NOT IN ('PENDING', 'REGISTERED_ON_REDIS', 'READY_TO_EXECUTE', 'CANCELLED_BY_NO_INTERACTIONS_FOUND')
	)
	INSERT INTO #TMP_SCHEDULE_LAST_EXECUTION
		SELECT [VCC],
				[BatchScheduleId],
				[BatchId],
				[ExecutionDate],
				[Status]
			FROM CTE_LAST_VALID_EXECUTIONS 
			WHERE RN = 1

			--SELECT * FROM [dbo].[BatchScheduleExecution] (NOLOCK) WHERE [BatchScheduleId] = '20211030_0141_prueba'

	-- CREAMOS UNA TABLA TEMPORAL PARA LA PROXIMA EJECUCION DE CADA AGENDA
	CREATE TABLE #TMP_SCHEDULE_NEXT_EXECUTION (
		VCC VARCHAR(50),
		BatchScheduleId VARCHAR(50),
		NextExecutionDate DATETIME
	)
	-- BUSCAMOS LAS ULTIMAS EJECUCIONES DE CADA AGENDA
	;WITH CTE_NEXT_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] ASC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[BatchType] = @BatchType
				AND BSE.[Status] IN ('PENDING', 'REGISTERED_ON_REDIS')
	)
	INSERT INTO #TMP_SCHEDULE_NEXT_EXECUTION
		SELECT [VCC],
				[BatchScheduleId],
				[ExecutionDate]
			FROM CTE_NEXT_EXECUTIONS 
			WHERE RN = 1



	-- BUSCAMOS LOS RESUMENES DE LAS EJECUCIONES
	;WITH CTE_SUMMARY AS (
		SELECT BS.[VCC], 
				BS.[Id]																							'BatchScheduleId',	
				COUNT(BSE.[Id])																					'Total',
				COUNT(IIF(BSE.[STATUS] LIKE 'REGISTERED_%', 1, NULL))											'Preparing',
				COUNT(IIF(BSE.[STATUS] LIKE '%_CREATED' OR BSE.[STATUS] LIKE '%_STARTED', 1, NULL))				'Running',
				COUNT(IIF(BSE.[STATUS] LIKE 'CANCELLED_%', 1, NULL))											'Cancelled',
				COUNT(IIF(BSE.[STATUS] LIKE 'COMPLETED%' OR BSE.[STATUS] = 'FAILED', 1, NULL))					'Finished',
				COUNT(IIF(BSE.[STATUS] = 'COMPLETED', 1, NULL))													'Succeed',
				COUNT(IIF(BSE.[STATUS] LIKE '%_WITH_ERRORS', 1, NULL))											'Error',
				COUNT(IIF(BSE.[STATUS] LIKE '%FAILED%', 1, NULL))												'Failed'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[BatchType] = @BatchType
				AND BS.[Status] IN ('CREATED', 'RUNNING', 'PAUSED', 'FINISHED')
				AND BSE.[Status] <> 'PENDING'
			GROUP BY BS.[VCC], BS.[Id]
	)
		SELECT BS.[VCC]																	'vcc',
				BS.[Id]																	'id',
				BS.[BatchType]															'batchType',
				BS.[Frequency]															'frequency',
				--BS.[Weekday]															'weekday',
				--BS.[Monthday]															'monthday',
				BS.[DaysInterval]														'daysInterval',
				BS.[HoursInterval]														'hoursInterval',
				BS.[StartDate]															'startDate',
				BS.[EndDate]															'endDate',
				BS.[FirstExecutionDate]													'firstExecutionDate',
				BS.[Status]																'status',
				--BS.[LastExecutionDate]													'lastExecutionDate',
				-- BS.[FinalExecutionDate]													'finalExecutionDate', 
				ISNULL(CTE_S.[Total], 0)												'total',
				ISNULL(CTE_S.[Preparing], 0)											'preparing',
				ISNULL(CTE_S.[Running], 0)												'running',
				ISNULL(CTE_S.[Cancelled], 0)											'cancelled',
				ISNULL(CTE_S.[Finished], 0)												'finished',
				ISNULL(CTE_S.[Succeed], 0)												'succeed',
				ISNULL(CTE_S.[Error], 0)												'error',
				ISNULL(CTE_S.[Failed], 0)												'failed',
				TMP_LE.[LastExecutionDate]												'lastExecutionDate',
				TMP_LE.[Status]															'lastExecutionStatus',
				TMP_NE.[NextExecutionDate]												'nextExecutionDate',
				BS.[CreatedDate]														'createdDate',
				BS.[CreatedByUserId]													'createdByUserId',
				BS.[LastModifiedDate]													'lastModifiedDate',
				BS.[LastModifiedByUserId]												'lastModifiedByUserId'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN CTE_SUMMARY CTE_S
				ON CTE_S.[VCC] = BS.[VCC]
					AND CTE_S.[BatchScheduleId] = BS.[Id]
			LEFT JOIN #TMP_SCHEDULE_LAST_EXECUTION TMP_LE 
				ON TMP_LE.[VCC] = BS.[VCC]
					AND TMP_LE.[BatchScheduleId] = BS.[Id]
			LEFT JOIN #TMP_SCHEDULE_NEXT_EXECUTION TMP_NE 
				ON TMP_NE.[VCC] = BS.[VCC]
					AND TMP_NE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[BatchType] = @BatchType
				AND ISNULL(BS.[Id], '') LIKE CASE WHEN @SearchCriteria = 'NAME' THEN '%' + @SearchExpression + '%' ELSE '%' END

	-- ELIMINAMOS LAS TABLAS TEMPORALES
	IF OBJECT_ID('tempdb..#TMP_SCHEDULE_LAST_EXECUTION') IS NOT NULL DROP TABLE #TMP_SCHEDULE_LAST_EXECUTION
	IF OBJECT_ID('tempdb..#TMP_SCHEDULE_NEXT_EXECUTION') IS NOT NULL DROP TABLE #TMP_SCHEDULE_NEXT_EXECUTION
		
	

	/*
	-- BUSCAMOS LAS ULTIMAS EJECUCIONES DE CADA AGENDA
	;WITH CTE_LAST_VALID_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] DESC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[Status] IN ('CREATED', 'RUNNING', 'PAUSED')
				AND BSE.[Status] NOT IN ('PENDING', 'REGISTERED_ON_REDIS', 'CANCELLED_BY_NO_INTERACTIONS_FOUND')
				-- AND BSE.[Status] = 'COMPLETED'
	),
	CTE_LAST_EXECUTIONS AS (
		SELECT CTE_VE.[VCC], 
				CTE_VE.[BatchScheduleId], 
				CTE_VE.[BatchId], 
				CASE WHEN CTE_VE.[Status] = 'REGISTERED_ON_REDIS' THEN NULL ELSE CTE_VE.[ExecutionDate] END		'LastExecutionDate', 
				CTE_VE.[Status]
			FROM CTE_LAST_VALID_EXECUTIONS CTE_VE
			WHERE CTE_VE.[RN] = 1
	),
	CTE_NEXT_VALID_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				CTE_LA.[LastExecutionDate],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] ASC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			INNER JOIN CTE_LAST_EXECUTIONS CTE_LA
				ON CTE_LA.[VCC] = BS.[VCC]
					AND CTE_LA.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BSE.[Status] = 'PENDING'
	),
	CTE_NEXT_EXECUTIONS AS (
		SELECT CTE_VE.[VCC], 
				CTE_VE.[BatchScheduleId], 
				CTE_VE.[BatchId], 
				CTE_VE.[ExecutionDate]																			'NextExecutionDate', 
				CTE_VE.[LastExecutionDate]																		'LastExecutionDate', 
				CTE_VE.[Status]
			FROM CTE_NEXT_VALID_EXECUTIONS CTE_VE
			WHERE CTE_VE.[RN] = 1
	),
	CTE_SUMMARY AS (
		SELECT BS.[VCC], 
				BS.[Id]																							'BatchScheduleId',	
				CTE_NE.[BatchId], 
				CTE_NE.[NextExecutionDate], 
				CTE_NE.[LastExecutionDate], 
				CTE_NE.[Status],
				COUNT(BSE.[Id])																					'Total',
				COUNT(IIF(BSE.[STATUS] LIKE 'REGISTERED_%', 1, NULL))											'Preparing',
				COUNT(IIF(BSE.[STATUS] LIKE '%_CREATED' OR BSE.[STATUS] LIKE '%_STARTED', 1, NULL))				'Running',
				COUNT(IIF(BSE.[STATUS] LIKE 'CANCELLED_%', 1, NULL))											'Cancelled',
				COUNT(IIF(BSE.[STATUS] LIKE 'COMPLETED%' OR BSE.[STATUS] = 'FAILED', 1, NULL))					'Finished',
				COUNT(IIF(BSE.[STATUS] = 'COMPLETED', 1, NULL))													'Succeed',
				COUNT(IIF(BSE.[STATUS] LIKE '%_WITH_ERRORS', 1, NULL))											'Error',
				COUNT(IIF(BSE.[STATUS] LIKE '%FAILED%', 1, NULL))												'Failed'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			LEFT JOIN CTE_NEXT_EXECUTIONS CTE_NE 
				ON CTE_NE.[VCC] = BS.[VCC]
					AND CTE_NE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[Status] IN ('CREATED', 'RUNNING', 'PAUSED')
				AND BSE.[Status] <> 'PENDING'
			GROUP BY BS.[VCC], BS.[Id], CTE_NE.[BatchId], CTE_NE.[NextExecutionDate], CTE_NE.[LastExecutionDate], CTE_NE.[Status]
	)-- select * from CTE_SUMMARY
		SELECT BS.[VCC]																	'vcc',
				BS.[Id]																	'id',
				BS.[BatchType]															'batchType',
				BS.[Frequency]															'frequency',
				--BS.[Weekday]															'weekday',
				--BS.[Monthday]															'monthday',
				BS.[DaysInterval]														'daysInterval',
				BS.[HoursInterval]														'hoursInterval',
				BS.[StartDate]															'startDate',
				BS.[EndDate]															'endDate',
				BS.[FirstExecutionDate]													'firstExecutionDate',
				BS.[Status]																'status',
				--BS.[LastExecutionDate]													'lastExecutionDate',
				-- BS.[FinalExecutionDate]													'finalExecutionDate', 
				ISNULL(CTE_S.[Total], 0)												'total',
				ISNULL(CTE_S.[Preparing], 0)											'preparing',
				ISNULL(CTE_S.[Running], 0)												'running',
				ISNULL(CTE_S.[Cancelled], 0)											'cancelled',
				ISNULL(CTE_S.[Finished], 0)												'finished',
				ISNULL(CTE_S.[Succeed], 0)												'succeed',
				ISNULL(CTE_S.[Error], 0)												'error',
				ISNULL(CTE_S.[Failed], 0)												'failed',
				CTE_S.[LastExecutionDate]												'lastExecutionDate',
				CTE_S.[Status]															'lastExecutionStatus',
				CTE_S.[NextExecutionDate]												'nextExecutionDate',
				BS.[CreatedDate]														'createdDate',
				BS.[CreatedByUserId]													'createdByUserId',
				BS.[LastModifiedDate]													'lastModifiedDate',
				BS.[LastModifiedByUserId]												'lastModifiedByUserId'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN CTE_SUMMARY CTE_S
				ON CTE_S.[VCC] = BS.[VCC]
					AND CTE_S.[BatchScheduleId] = BS.[Id]
			LEFT JOIN [dbo].[Process] P (NOLOCK)
				ON BS.[BatchType] = 'TRANSCRIPTION'
					AND P.[VCC] = CTE_S.[VCC]
					AND P.[Name] = CTE_S.[BatchId]
			LEFT JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON BS.[BatchType] = 'EVALUATION_PLAN'
					AND EP.[Instance] = CTE_S.[VCC]
					AND EP.[ID] = CTE_S.[BatchId]
			WHERE BS.[VCC] = @VCC
				AND ISNULL(BS.[Id], '') LIKE CASE WHEN @SearchCriteria = 'NAME' THEN '%' + @SearchExpression + '%' ELSE '%' END
	*/

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveBatchSchedule]...';


GO
ALTER PROCEDURE [dbo].[SaveBatchSchedule] (
	@VCC VARCHAR(50) = NULL,
	@Id VARCHAR(50) = NULL,
	@BatchType VARCHAR(50) = NULL, -- TRANSCRIPTION/STUDY(?)/EVALUATION_PLAN
	@Frequency VARCHAR(50) = NULL,
	@Weekday INT = NULL,
	@Monthday INT = NULL,
	@DaysInterval INT = NULL,
	@HoursInterval INT = NULL,
	@ExecutionHour VARCHAR(50) = NULL,
	@FirstExecutionDate DATETIME = NULL,
	@ExecutionDelay INT = NULL,
	@StartDate DATETIME = NULL,
	@EndDate DATETIME = NULL,
	@BatchData VARCHAR(MAX) = NULL,
	@ProcessFiltersId VARCHAR(50) = NULL,
	@Status VARCHAR(50) = NULL, -- CREATED/RUNNING/PAUSED/FINISHED
	@UserId VARCHAR(50) = NULL
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE REGISTRAR LOS ERRORES QUE PUEDEN OCURRIR DURANTE LA EJECUCION DE LAS COLAS
	SET XACT_ABORT, NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
		-- VALIDAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
		IF @VCC IS NULL 
			OR @Id IS NULL 
			OR @Frequency IS NULL 
			OR @StartDate IS NULL 
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABASE_ERROR_MISSING_PARAMETERS', 16, 16)

		--
		UPDATE [dbo].[BatchSchedule]
			SET [LastExecutionDate] = NULL,
				[Status] = ISNULL(@Status, [Status]),
				[LastModifiedDate] = GETUTCDATE(),
				[LastModifiedByUserId] = @UserId,
				[TimeStamp] = GETUTCDATE()
			WHERE [VCC] = @VCC
				AND [Id] = @Id
				AND [BatchType] = @BatchType
		
		-- SI NO SE ACTUALIZO NINGUN REGISTRO, LO INSERTAMOS
		IF @@ROWCOUNT = 0
		BEGIN
			--select * from BatchSchedule (nolock)
			-- INSERTAMOS EL REGISTRO EN LA TABLA DE ERROR
			INSERT INTO [dbo].[BatchSchedule] (
					[VCC], [Id], [BatchType], [Frequency], [Weekday],
					[Monthday], [DaysInterval], [HoursInterval], [StartDate], [EndDate],
					[FirstExecutionDate], [LastExecutionDate], [FinalExecutionDate], [ExecutionDelay], [BatchData], 
					[ProcessFiltersId], [Status], [CreatedDate], [CreatedByUserId], [TimeStamp]
				) VALUES (
					@VCC, @Id, @BatchType, @Frequency, @Weekday,
					@Monthday, @DaysInterval, @HoursInterval, @StartDate, @EndDate,
					@FirstExecutionDate, NULL, NULL, @ExecutionDelay, @BatchData, 
					@ProcessFiltersId, 'CREATED', GETUTCDATE(), @UserId, GETUTCDATE()
				)
		END

		SELECT 1 AS 'result'
    
	END TRY
    BEGIN CATCH
        --IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluationReviewCommitments]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluationReviewCommitments] (
	@VCC Varchar(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW-COMMITMENT
	SELECT ERC.[EvaluationPlanId]										'evaluationPlanId',
			ERC.[ID]													'id',
			AEP.[Score]													'score',
			ERC.[SupervisorId]											'supervisorId',
			CONCAT(U2.[FirstName], ' ', ISNULL(U2.[LastName], ''))		'supervisorName',
			ERC.[LargeInteractionId]									'largeInteractionId',
			ERC.[AgentId]												'agentId',
			CONCAT(U1.[FirstName], ' ', ISNULL(U1.[LastName], ''))		'agentName',
			ERC.[Commitment]											'commitment',
			ERC.[CreatedDate]											'eventDate',
			ERC.[CreatedDate]											'createdDate'
		FROM [dbo].[EvaluationReviewCommitment] ERC (NOLOCK) 
		LEFT JOIN [dbo].[User] U1 (NOLOCK)
			ON U1.[VCC] = ERC.[VCC]
				AND U1.[ID] = ERC.[AgentId]
		INNER JOIN [dbo].[User] U2 (NOLOCK)
			ON U2.[VCC] = ERC.[VCC]
				AND U2.[ID] = ERC.[SupervisorId]
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			ON AEP.[Instance] = ERC.[VCC]
				AND AEP.[IdEvaluationPlan] = ERC.[EvaluationPlanId]
				AND AEP.[IdInteraction] = ERC.[InteractionId]
				-- AND AEP.[IdAuditor] = ERC.[SupervisorId]
				AND AEP.[IdAgent] = ERC.[AgentId]
		WHERE ERC.[VCC] = @VCC
			AND ERC.[EvaluationPlanId] =  ISNULL(@EvaluationPlanId, ERC.[EvaluationPlanId])
			AND ERC.[InteractionId] = ISNULL(@InteractionId, ERC.[InteractionId])
			AND ERC.[SupervisorId] = ISNULL(@SupervisorId, ERC.[SupervisorId])
			AND ERC.[AgentId] = ISNULL(@AgentId, ERC.[AgentId])
		ORDER BY [ERC].[CreatedDate] DESC

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveEvaluationReviewCommitment]...';


GO
ALTER PROCEDURE [dbo].[SaveEvaluationReviewCommitment] (
	@VCC VARCHAR(50) = NULL, 
	@Id VARCHAR(50) = NULL,
	@LargeInteractionId VARCHAR(255) = NULL,
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL,
	@Commitment VARCHAR(500) = NULL,
	@SaveUserId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- ACTUALIZAMOS EL REGISTRO CORRESPONDIENTE A LA REVISION
	UPDATE [dbo].[EvaluationReviewCommitment]
		SET [Commitment] = @Commitment,
			[LastModifiedDate] = GETUTCDATE(),
			[LastModifiedUserId] = @SaveUserId,
			[Timestamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [EvaluationPlanId] = @EvaluationPlanId
			AND [InteractionId] = @InteractionId
			AND [SupervisorId] = @SupervisorId
			AND [ID] = @Id
			
	-- SI NO SE ACTUALIZO NINGUN REGISTRO, LO INSERTAMOS
	IF @@ROWCOUNT = 0
	BEGIN
		-- 
		INSERT INTO [dbo].[EvaluationReviewCommitment] (
				[VCC],
				[LargeInteractionId],
				[EvaluationPlanId],
				[InteractionId],
				[SupervisorId],
				[AgentId],
				[Commitment],
				[CreatedDate],
				[CreatedUserId],
				[Timestamp]
			) VALUES (
				@VCC,
				@LargeInteractionId,
				@EvaluationPlanId,
				@InteractionId,
				@SupervisorId,
				@AgentId,
				@Commitment,
				GETUTCDATE(),
				@SaveUserId,
				GETUTCDATE()
			)
	END

	-- 
    SELECT 1 AS 'result'
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluationReview]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluationReview] (
	@VCC Varchar(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW
	SELECT ER.[VCC]													'vcc',
			ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[InteractionId]										'interactionId',
			ER.[SupervisorId]										'supervisorId',
			ER.[Review]												'review'
		FROM [dbo].[EvaluationReview] ER (NOLOCK) 
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])

	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW-COMMITMENT
	EXEC [dbo].[GetEvaluationReviewCommitments] @VCC, @EvaluationPlanId, @InteractionId, @SupervisorId, @AgentId
	/*
	SELECT ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[SupervisorId]										'supervisorId',
			ERC.[LargeInteractionId]								'largeInteractionId',
			ERC.[AgentId]											'agentId',
			ERC.[Commitment]										'commitment',
			ERC.[CreatedDate]										'eventDate',
			ERC.[CreatedDate]										'createdDate'
		FROM [dbo].[EvaluationReviewCommitment] ERC (NOLOCK) 
		INNER JOIN [dbo].[EvaluationReview] ER (NOLOCK)
			ON ER.[VCC] = ERC.[VCC]
				AND ER.[Id] = ERC.[EvaluationReviewId]
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])
			AND ERC.[AgentId] = ISNULL(@AgentId, ERC.[AgentId])
		ORDER BY [ERC].[CreatedDate] DESC
	*/
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[BulkAbilityCognitive]...';


GO
ALTER PROCEDURE [dbo].[BulkAbilityCognitive]
AS
BEGIN
	SET NOCOUNT ON
	--select * from Dummy 
	--truncate table Dummy
	/*
	CREATE TABLE TMP_EVALUATIONPLANABILITY(
		VCC VARCHAR(50),
		ProcessId VARCHAR(50),
		EvaluationPlanId  VARCHAR(200),
		ID VARCHAR(250),
		Section  VARCHAR(50),
		Part VARCHAR(50),
		QueryId VARCHAR(50),
		TranscriptionId VARCHAR(200),
		NluId VARCHAR(50),
		IntentName VARCHAR(50),
		EndDate VARCHAR(50),
		Channel VARCHAR(50),
		Campaign VARCHAR(50)
	)
	*/

	/*insert into DummyEvaluationPlanAbility ([VCC]) values ('BULK')
	insert into TMP_EVALUATIONPLANABILITY ([VCC]
		  ,[ProcessId]
		  ,[EvaluationPlanId]
		  ,[ID]
		  ,[Section]
		  ,[Part]
		  ,[QueryId]
		  ,[TranscriptionId]
		  ,[NluId]
		  ,[IntentName]
		  ,[EndDate]
		  ,[Channel]
		  ,[Campaign])  
	SELECT [VCC]
		  ,[ProcessId]
		  ,[EvaluationPlanId]
		  ,[ID]
		  ,[Section]
		  ,[Part]
		  ,[QueryId]
		  ,[TranscriptionId]
		  ,[NluId]
		  ,[IntentName]
		  ,[EndDate]
		  ,[Channel]
		  ,[Campaign]
	  FROM [dbo].[#AbilityCognitiveTemp]
	*/  

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT ACTMP.[VCC],
							ACTMP.[EvaluationPlanId] 'EVALUATION_PLAN_ID'
						FROM [#AbilityCognitiveTemp] ACTMP (NOLOCK)
						WHERE ACTMP.[VCC] IS NOT NULL 
							AND ACTMP.[EvaluationPlanId] IS NOT NULL

	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_ID VARCHAR(100) = ''

	-- ABRIMOS Y RECORREMOS EL ARRAY DE CANALES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS PLANES QUE AUN NO LOS TIENEN
		EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'AUTOMATIC'
			
		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	
	/* Script para actualizar a puntaje 100 la calificacion de cada habilidad retornada por luis */
	/*
	SELECT EP.[Description],
			ACTMP.[ID],
			I.[IntentId],
			I.[Name],
			A.[Title],
			AEP.Completed,
			ER.[Qualification],
			I.[AppId]
			*/

	UPDATE ER
		SET ER.[Qualification] = (AEF.[Score] * S.[Value]) / 100,
			ER.[OwnScore] = (AEF.[Score] * S.[Value]) / 100,
			ER.[ScoreDescription] = S.[Description],
			ER.[AbilityInnerScore] = S.[Value]
		FROM [#AbilityCognitiveTemp] ACTMP 
		INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
			ON EP.[ID] = ACTMP.[EvaluationPlanId]
		INNER JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
			ON AEF.[Instance] = EP.[Instance]
				AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				AND AEF.[IdAbility] = ACTMP.[AbilityId]
		INNER JOIN EvaluationResult ER (NOLOCK)
			ON ER.[Instance] = EP.[Instance] 
				AND ER.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				AND ER.[IdInteraction] = ACTMP.[ID]
		INNER JOIN [dbo].[Ability] A (NOLOCK) 
	       ON A.[Instance] = ER.[Instance] 
	            AND A.[ID] = ER.[IdAbility]
		INNER JOIN [dbo].[Score] S (NOLOCK)
			ON S.[IdAbility] = ACTMP.[AbilityId]
				AND S.[Value] = IIF(A.[IsNegative] = 1, 0, 100)
		WHERE AEF.[IdAbility] = ER.[IdAbility]
			AND ER.[IdAuditor] = 'SPEECH'
	
	/* Script para actualizar la tabla AuditorEvaluationPlan a Completed y Suma de Scores de la evaluacion */
	UPDATE AEP
		SET --AEP.[Completed] = '1',
			AEP.[Completed] = CASE WHEN AEPR.[Evaluation_Mode] = 'X' AND AEPR.[MinAutomaticQualification] <= AEPR.[SCORE] THEN '0' ELSE '1' END,
			AEP.[StatusDescription] = CASE WHEN AEPR.[Evaluation_Mode] = 'X' AND AEPR.[MinAutomaticQualification] <= AEPR.[SCORE] THEN 'NEW' ELSE 'COMPLETED' END,
			AEP.[Score] = AEPR.[SCORE],
			AEP.[AutomaticScore] = AEPR.[SCORE],
			-- AEP.[ManualScore] = AEPR.[SCORE], -- UNA EVALUACION AUTOMATICA DEBE TENER 0 DE MANUALSCORE
			AEP.[ManualScore] = 0,
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP (NOLOCK)
		LEFT JOIN (
			SELECT AEP.[Instance],
				AEP.[IdEvaluationPlan],
				AEP.[IdInteraction],
				EP.[Evaluation_Mode],
				EF.[MinAutomaticQualification],
				SUM(ER.[Qualification]) AS SCORE
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN EvaluationPlan EP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.[ID] = AEP.[IdEvaluationPlan] 
			LEFT JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = AEP.[Instance]
					AND EF.[ID] = EP.[IdEvaluationFormat]
			LEFT JOIN EvaluationResult ER (NOLOCK)
				ON ER.[Instance] = AEP.[Instance]
					AND ER.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND ER.[IdInteraction] = AEP.[IdInteraction]
			LEFT JOIN AbilityEvaluationFormat AEF (NOLOCK) 
				ON AEF.[Instance] = EP.[Instance]
					AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			LEFT JOIN (SELECT DISTINCT ACTMP.[VCC],
									ACTMP.[EvaluationPlanId]
								FROM [#AbilityCognitiveTemp] ACTMP (NOLOCK)
								WHERE ACTMP.[VCC] IS NOT NULL 
									AND ACTMP.[EvaluationPlanId] IS NOT NULL) TMP 
				ON TMP.[VCC] = AEP.[Instance]
					AND TMP.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
			WHERE TMP.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
				AND AEP.[IdAuditor] = 'SPEECH'
			GROUP BY AEP.[Instance], AEP.[IdEvaluationPlan], AEP.[IdInteraction], EP.[Evaluation_Mode], EF.[MinAutomaticQualification]
		) AEPR 
		ON AEPR.[Instance] = AEP.[Instance]
			AND AEPR.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
			AND AEPR.[IdInteraction] = AEP.[IdInteraction]
		WHERE AEPR.[Instance] = AEP.[Instance]
			AND AEPR.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
			AND AEPR.[IdInteraction] = AEP.[IdInteraction]
	
	;
	/****************************************************************************************/
	/*INICIO SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/****************************************************************************************/
	
	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA DETERMINAR LAS INTERACCIONES QUE TIENEN HABILIDAD(ES) PENALIZADA(S) POR NOTA CERO
	--  ORDENANDO POR PRIORIDAD (INTERACCION 1, GRUPO 2 Y SUBGRUPO 3)
	WITH CTEFP AS (
		SELECT DISTINCT 
				ER.[Instance],
				ER.[IdInteraction],
				ER.[IdEvaluationPlan],
				ER.[IdEvaluationFormat],
				ER.[IdAbility],
				CASE WHEN ER.[Qualification] = 0 AND AEF.[Penalizes] <> 'NO' THEN 1 ELSE 0 END 'Penalized',
				AEF.[Penalizes],
				CASE AEF.[Penalizes]
					WHEN 'INT' THEN ER.[IdInteraction] 
					WHEN 'GRP' THEN ER.[IdGroup] 
					WHEN 'SGR' THEN ER.[IdSubGroup] 
				END 'PenalizedOn',
				RN = ROW_NUMBER() OVER(PARTITION BY ER.[IdInteraction], CASE WHEN ER.[Qualification] = 0 THEN 1 ELSE 0 END 
					ORDER BY CASE AEF.[Penalizes]
					WHEN 'INT' THEN 1 
					WHEN 'GRP' THEN 2 
					WHEN 'SGR' THEN 3 
				END)
			FROM [EvaluationResult] ER (NOLOCK) 
			LEFT JOIN [AbilityEvaluationFormat] AEF (NOLOCK) 
				ON AEF.[Instance] = ER.[Instance] 
					AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM [#AbilityCognitiveTemp]) 
				AND ER.[Qualification] = 0 
				AND AEF.[Penalizes] <> 'NO'
			-- WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EPA.[EvaluationPlanId] FROM [DummyEvaluationPlanAbility] EPA (NOLOCK) WHERE EPA.[EvaluationPlanId] IS NOT NULL)
	),

	-- ALMACENAMOS EL RESULTADO AGRUPADO DE LAS EVALUACIONES EN UNA TABLA VARIABLE PARA HACER UN CRUCE DIRECTO CON
	--  LA TABLA AuditorEvaluationPlan
	CTEFS AS (
		SELECT ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				SUM(ER.[Qualification]) 'TOTAL_SCORE',
				SUM(ER.[Qualification] * CASE WHEN FP.[Penalized] IS NULL THEN 1 ELSE 0 END) 'PENALIZED_SCORE'
		
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN (
				-- HACEMOS UN CRUCE CON LA TABLA VARIABLE Y TOMAMOS SOLO UNA DE LAS PENALIZACIONES POR INTERACCION, EMPEZANDO 
				--  POR LA MAS PRIORITARIA (FP.[RN])
				SELECT DISTINCT FP.[Instance],
								FP.[IdEvaluationPlan], 
								FP.[Penalized],
								FP.[Penalizes], 
								FP.[PenalizedOn]
					FROM CTEFP FP (NOLOCK)
					WHERE FP.[Penalizes] <> 'NO'
						AND FP.[RN] = 1
			) FP
				ON FP.[Instance] = ER.[Instance]
					AND ER.[IdEvaluationPlan] = FP.[IdEvaluationPlan]
					AND CASE FP.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP.[PenalizedOn]
					AND FP.[Penalized] = 1
			--WHERE ER.[Instance] = 'multisalud'
			WHERE -- ER.[Instance] = FP.[Instance] -- ESTA LINEA CAUSA QUE NO SE ACTUALICEN LOS SCORES LAS EVALUACIONES QUE NO PENALIZAN
				-- AND 
				ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM [#AbilityCognitiveTemp])
			GROUP BY ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction]
	)
	--SELECT * FROM CTEFS

	-- ACTUALIZAMOS LOS REGISTROS DE EVALUACION CON LA NOTA PENALIZADA OBTENIDA EN LOS PASOS ANTERIORES
	UPDATE AEP 
		SET AEP.[Score] = FS.[PENALIZED_SCORE],
			AEP.[AutomaticScore] = FS.[PENALIZED_SCORE],
			AEP.[ManualScore] = 0,
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP 
		LEFT JOIN CTEFS FS (NOLOCK) 
			ON FS.[Instance] = AEP.[Instance] 
				AND FS.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
				AND FS.[IdInteraction] = AEP.[IdInteraction]
		WHERE FS.[Instance] IS NOT NULL
		
	/*************************************************************************************/
	/*FIN SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/*************************************************************************************/
     --insert into test(origin,content) values('BulkAbilityCognitive',(select *  from [dbo].[#AbilityCognitiveTemp] FOR JSON AUTO))
	DROP TABLE [dbo].[#AbilityCognitiveTemp];
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[DeleteEvaluationResultDraftBackup]...';


GO
ALTER PROCEDURE [dbo].[DeleteEvaluationResultDraftBackup] (
	@VCC VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@AuditorId VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON
	-- EL PRESENTE SP TIENE LA FINALIDAD DE ELIMINAR LOS REGISTROS DE RESPALDO PARA BORRADOR

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        
		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- DECLARAMOS UNA VARIABLE PARA VERIFICAR EL TIPO DEL PLAN
		DECLARE @IS_MIXED_EVALUATION_PLAN BIT = 0

		-- VERIFICAMOS QUE EL PLAN DE EVALUACION ES DEL TIPO MIXTO
		SELECT @IS_MIXED_EVALUATION_PLAN = IIF (EP.[Evaluation_Mode] = 'X', 1, 0) 
			FROM [dbo].[EvaluationPlan] EP (NOLOCK) 
			WHERE EP.[Instance] = @VCC
				AND EP.[ID] = @EvaluationPlanId

		-- DECLARAMOS UNA VARIABLE PARA VERIFICAR SI LA AUDITORIA YA ESTA GUARDADA COMO BORRADOR
		DECLARE @EXISTS_DRAFT_DATA BIT = 0

		IF EXISTS (
			SELECT 1 
				FROM [dbo].[EvaluationResult] (NOLOCK)
				WHERE [Instance] = @VCC
					AND [IdEvaluationPlan] = @EvaluationPlanId
					AND [IdInteraction] = @InteractionId
					AND [IdEvaluator] = 'SPEECH'
					AND [IdAuditor] = @AuditorId + '-DRAFT'
		)
			SET @EXISTS_DRAFT_DATA = 1

		IF @IS_MIXED_EVALUATION_PLAN = 1 AND @EXISTS_DRAFT_DATA = 1
		BEGIN
			-- RESTAURAMOS LOS RESULTADOS DE LA PARTE AUTOMATICA
			DELETE [dbo].[EvaluationResult]
				WHERE [Instance] = @VCC
					AND [IdEvaluationPlan] = @EvaluationPlanId
					AND [IdInteraction] = @InteractionId
					AND [IdEvaluator] = 'SPEECH'
					AND [IdAuditor] = @AuditorId + '-DRAFT'
		END 

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
	
	
    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetAllegroAgents]...';


GO
ALTER PROCEDURE [dbo].[GetAllegroAgents] (
	@Ip VARCHAR(50), 
	@VCC VARCHAR(50), 
	@Type INT, 
	@Campaigns VARCHAR(MAX) = NULL
) AS
BEGIN
	-- ESTE SP RETORNA LA LISTA DE AGENTES DEL VCC SEGUN LAS CAMPANAS

	-- DECLARAMOS VARIABLES PARA ARMAR LA CONSULTA
	DECLARE @SQL VARCHAR(MAX) = NULL
	DECLARE @TABLE_MMPRODAT VARCHAR(100) = NULL

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF @Type = 0
	BEGIN  
		SET @TABLE_MMPRODAT = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TABLE_MMPRODAT = '[MMProDat].[dbo].'
	END

	-- ARMAMOS LA QUERY optimizada para agentes sin linea asignada
	SET @Sql = '
		SELECT U.[VCC]								''vcc'',
				UC.[CampaignId]						''campaignId'',
				U.[Id]								''userId'',
				U.[Name]							''userName'',
				A.[WorkgroupId]						''workGroupId''
			FROM ' + @TABLE_MMPRODAT + '[User] U (NOLOCK)
			LEFT JOIN ' + @TABLE_MMPRODAT + '[GroupApplication] GA (NOLOCK)
				ON (
						GA.[VCC] = U.[VCC]
						OR
						GA.[VCC] = ''system''
					)
					AND GA.[GroupId] = U.[UserGroup]
			LEFT JOIN ' + @TABLE_MMPRODAT + '[Agent] A (NOLOCK)
				ON A.[VCC] = U.[VCC]
					AND A.[UserId] = U.[Id] 
			LEFT JOIN ' + @TABLE_MMPRODAT + '[UserCampaign] UC (NOLOCK) 
				ON UC.VCC = U.[VCC] 
					AND UC.[UserId] = U.[Id] 
			WHERE U.[VCC] = ''' + @VCC + '''
				AND GA.ApplicationId = ''baragent'' '

	/*
	-- ARMAMOS LA QUERY
	SET @Sql = '
		SET NOCOUNT ON
		SELECT UC.[VCC]							''vcc'',
				UC.[CampaignId]						''campaignId'',
				UC.[UserId]							''userId'',
				U.[Name]							''userName'',
				A.[WorkgroupId]						''workGroupId''
			FROM ' + @TABLE_MMPRODAT + '[Agent]  A (NOLOCK)
			LEFT JOIN ' + @TABLE_MMPRODAT + '[User] U (NOLOCK)
				ON U.[VCC] = A.[VCC]
					AND U.[Id] = A.[UserId]
			LEFT JOIN ' + @TABLE_MMPRODAT + '[UserCampaign] UC (NOLOCK) 
				ON UC.VCC = A.VCC 
					AND UC.UserId = A.UserId
			WHERE UC.[VCC] = ''' + @VCC + ''''
	*/

	IF @Campaigns IS NOT NULL AND @Campaigns <> ''
		SET @Sql += 'AND UC.[CampaignId] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '

	SET @Sql += ' 
		SET NOCOUNT OFF'

	-- select @Sql
	EXEC (@Sql)

END
GO
PRINT N'Modificando [dbo].[GetBatchScheduleExecutionsByCriteria]...';


GO
ALTER PROCEDURE [dbo].[GetBatchScheduleExecutionsByCriteria] (
	@VCC VARCHAR(50) = NULL, 
	@SearchCriteria VARCHAR(50) = NULL,
	@SearchExpression VARCHAR(500) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	DECLARE @SQL VARCHAR(MAX) = ''
	-- DECLARAMOS CADENAS PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
    DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	SET @SQL_SELECT = '
		SELECT BSE.[VCC]									''vcc'',
				BSE.[Id]									''id'', 
				BSE.[BatchScheduleId]						''batchScheduleId'', 
				BSE.[BatchId]								''batchId'', 
				BSE.[ExecutionDate]							''executionDate'', 
				BS.[ExecutionDelay]							''executionDelay'',
				BSE.[Order]									''order'', 
				BSE.[Status]								''status'', 
				BSE.[CreatedDate]							''createdDate'',
				BSE.[CreatedByUserId]						''createdByUserId'',
				BSE.[LastModifiedDate]						''lastModifiedDate'',
				BSE.[LastModifiedByUserId]					''lastModifiedByUserId'',
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] DESC) '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [dbo].[BatchScheduleExecution] BSE (NOLOCK)
			INNER JOIN [dbo].[BatchSchedule] BS (NOLOCK)
				ON BS.[VCC] = BSE.[VCC]
					AND BS.[Id] = BSE.[BatchScheduleId] '

	-- ARMAMOS LA PARTE BASE DE FILTROS
	SET @FILTERS_FIXED_PART = '
			WHERE BSE.[Id] IS NOT NULL '

	-- 
	IF @VCC IS NOT NULL
		SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[VCC] = ''' + @VCC + ''' '

	/* DEPRECATED
	-- CUANDO SE HACE BUSQUEDA POR ULTIMA EJECUCIONES
	IF @SearchCriteria = 'ALREADY_EXECUTED_BY_BS_ID'
		SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] = ''' + @SearchExpression + ''' 
				AND BSE.[Status] <> ''PENDING'' '
	*/
	
	-- CUANDO SE HACE BUSQUEDA POR NO EJECUTADAS
	IF @SearchCriteria = 'NO_EXECUTED_BY_SCHEDULE_ID'
	SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','','')) 
				AND BSE.[Status] IN (''PENDING'', ''REGISTERED_ON_REDIS'') '

	-- CUANDO SE HACE BUSQUEDA MULTIPLE POR IDS
	IF @SearchCriteria = 'NOT_CREATED_BY_BS_ID'
		SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','',''))
				AND BSE.[BatchId] IS NULL 
				AND BSE.[Status] NOT LIKE ''CANCELLED_%'' '

	-- CUANDO SE HACE BUSQUEDA POR ULTIMA EJECUCIONES
	IF @SearchCriteria = 'LAST_CREATED_EXECUTIONS'
	SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','','')) '
	
	-- EL FILTRO POR DEFECTO
	IF @SQL_EXTRA IS NULL OR @SQL_EXTRA  = ''
		SET @SQL_EXTRA += '
			ORDER BY BSE.[ExecutionDate] ASC, BSE.[BatchScheduleId] '

	
	
	-- CUANDO SE HACE BUSQUEDA POR ULTIMA EJECUCIONES
	IF @SearchCriteria = 'LAST_CREATED_EXECUTIONS'
	BEGIN
		-- UNIMOS LAS PARTES DEL QUERY
		SET @SQL_SELECT += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART
		
		--
		SET @SQL = ';WITH CTE AS (' + @SQL_SELECT + ')'

	
		SET @SQL += 'SELECT * FROM CTE BSE WHERE RN = 1 ORDER BY BSE.[ExecutionDate] DESC, BSE.[BatchScheduleId] '
	END
	ELSE
	BEGIN
		-- UNIMOS LAS PARTES DEL QUERY
		SET @SQL_SELECT += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA
		SET @SQL += @SQL_SELECT
	END

	-- EJECUTAMOS LA QUERY
	EXEC (@SQL)

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluations]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluations] (
	@Instance Varchar(50) = NULL,
	@IdAuditor VARCHAR(MAX) = NULL,
	@IdAgent Varchar(MAX) = NULL,
   	@IdCampaign VARCHAR(MAX) = NULL,
	@IdEvaluationPlan VARCHAR(MAX) = NULL,
 	@EvaluationDateFrom VARCHAR(50) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(50) = '2050-01-01T23:59:59',
	@EvaluationHourFrom VARCHAR(50) = '00:00:00',
    @EvaluationHourTo VARCHAR(50) = '23:59:59',
	@InteractionMinDuration Int = 0,
    @InteractionMaxDuration Int = 86400,
    @InteractionOrigins Varchar(50) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@EvaluationTypes Varchar(MAX) = NULL,
	@InteractionTags Varchar(MAX) = NULL,
	@InteractionFormats Varchar(50) = NULL,
	@InteractionCoached VARCHAR(50) = NULL,
	@InteractionIds     VARCHAR(MAX) = NULL,
	@EvaluationsLimit Int = 0
)
AS
BEGIN
	SET NOCOUNT ON
	IF (@EvaluationHourFrom = '') SET @EvaluationHourFrom = '00:00:00';
	IF (@EvaluationHourTo = '') SET @EvaluationHourTo = '23:59:59';
	
	-- SI ORIGINS TIENE DOS VALORES, IGNORAMOS EL FILTRO
	IF (SELECT COUNT(*) FROM [dbo].[split](@InteractionOrigins, ',')) = 2 SET @InteractionOrigins = ''
	
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	-- EMULAMOS UNA NUEVA TABLA EN BASE A INTERACTIONEVALUATIONPLAN
	SET @SQL_SELECT_1 += '
		;WITH CTE AS (
			SELECT ER.[Instance],
					ER.[IdEvaluationPlan],
					ER.[IdInteraction], 
					ER.[IdAgent],
					IEP.[AgentName],
					RN = ROW_NUMBER() OVER(PARTITION BY IEP.[Instance], IEP.[IdEvaluationPlan], IEP.[IdInteraction] ORDER BY IEP.[CreatedDate] ASC)
				FROM [dbo].[EvaluationResult] ER (NOLOCK) 
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = ER.[Instance]
						AND EP.[Id] =  ER.[IdEvaluationPlan]
				INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
					ON (AEP.[Instance] = ER.[Instance] 
						AND AEP.[IdAuditor] = ER.[IdAuditor] 
						AND AEP.[IdInteraction] = ER.[IdInteraction] 
						AND AEP.[InteractionType] = ER.[InteractionType] 
						AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
				INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
					ON IEP.[Instance] = ER.[Instance] 
						AND IEP.[IdEvaluationPlan] = EP.[ID]
						AND IEP.[IdInteraction] = ER.[IdInteraction]
						AND IEP.[IdAgent] = ER.[IdAgent]
				WHERE ER.[Instance] = ''' + @Instance + '''
					AND ER.[EvaluationDate] BETWEEN ''' + @EvaluationDateFrom + '''AND ''' + @EvaluationDateTo + '''
					AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
					AND AEP.[Completed] = 1
		) '

	SET @SQL_SELECT_1 += '
		SELECT '

	SET @SQL_SELECT_1 += '
				AEP.Completed						''completed'',
				AEP.[StatusDescription]             ''statusDescription'',
				A.[ErrorMessage]                    ''errorMessage'',
    			AEP.score							''qualification'',
    			AEP.IdAuditor						''idAuditor'',
    			U.FirstName + '' '' + U.LastName	''auditorName'',
    			MAX(ER.EvaluationDate)				''evaluationDate'',
    			AEP.IdEvaluationPlan				''idEvaluationPlan'',
				EP.Description						''evaluationPlan'',
				EP.[Evaluation_Mode]				''evaluationType'',
    			AEP.idAgent							''idAgent'',
    			C.[AgentName]						''agentName'',							-- NOMBRE DEL AGENTE
				AEP.idInteraction					''idInteraction'',
				AEP.InteractionDate					''interactionDate'',
    			AEP.InteractionType					''interactionType'',
    			AEP.IdCampaign						''idCampaign'',
				E.[Type]							''environmentType'',
				COUNT(ERC.[Id])						''commitments'' '

	SET @SQL_FROM += '
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = ER.[Instance] 
					AND EP.[ID] = ER.IdEvaluationPlan) 
			LEFT JOIN [AuditorEvaluationPlan] AEP (NOLOCK) 
				ON (AEP.[Instance] = ER.[Instance] 
					AND AEP.[IdAuditor] = ER.[IdAuditor] 
					AND AEP.[IdInteraction] = ER.[IdInteraction] 
					AND AEP.[InteractionType] = ER.[InteractionType] 
					AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
			LEFT JOIN [dbo].[EvaluationReviewCommitment] ERC (NOLOCK)
				ON ERC.[VCC] = AEP.[Instance] 
					AND ERC.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERC.[InteractionId] = AEP.[IdInteraction]
					AND ERC.[SupervisorId] = AEP.[IdAuditor] 
					AND ERC.[AgentId] = AEP.[idAgent]
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
			    ON A.[VCC] = AEP.[Instance]
			        AND A.[ID] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[Environment] E (NOLOCK)
				ON E.[VCC] = ER.[Instance]
					AND E.[Name] = EP.[EnvironmentId]
			LEFT JOIN [User] U (NOLOCK) 
				ON (U.[VCC] = ER.[Instance] 
					AND U.ID = AEP.IdAuditor) 
			LEFT JOIN CTE C (NOLOCK) 
				ON C.[Instance] = ER.[Instance]
					AND C.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
					AND C.[IdInteraction] = ER.[IdInteraction] 
					AND C.[IdAgent] = ER.[IdAgent] 
					AND C.RN = 1 '

	SET @FILTERS_FIXED_PART = '
			WHERE ER.[Instance] = ''' + @Instance + '''
				AND ER.[EvaluationDate] >= ''' + @EvaluationDateFrom + '''
				AND ER.[EvaluationDate] <= ''' + @EvaluationDateTo + '''
				AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
				AND AEP.[Completed] = 1 ' -- LINEA PARA FILTRAR EVALUACIONES COMPLETADAS

	IF (@IdAuditor IS NOT NULL AND @IdAuditor != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAuditor] IN (SELECT Value FROM [dbo].[split](''' + @IdAuditor + ''','','')) '
	IF (@IdAgent IS NOT NULL AND @IdAgent != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgent + ''','','')) '
	IF (@IdCampaign IS NOT NULL AND @IdCampaign != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaign + ''','','')) '
	IF (@IdEvaluationPlan IS NOT NULL AND @IdEvaluationPlan != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[ID] IN (SELECT Value FROM [dbo].[split](''' + @IdEvaluationPlan + ''','','')) '
	IF (CAST(@EvaluationHourFrom AS TIME) <= CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) BETWEEN ''' + @EvaluationHourFrom + ''' AND ''' + @EvaluationHourTo + ''' '
	IF (CAST(@EvaluationHourFrom AS TIME) > CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) NOT BETWEEN ''' + @EvaluationHourTo + ''' AND ''' + @EvaluationHourFrom + ''' '
	IF (@InteractionMinDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] >= ' + (SELECT CONVERT(varchar(10), @InteractionMinDuration)) + ' '
	IF (@InteractionMaxDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] <= ' + (SELECT CONVERT(varchar(10), @InteractionMaxDuration))+ ' '
	IF (@InteractionOrigins IS NOT NULL AND @InteractionOrigins != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionOrigin] IN (SELECT Value FROM [dbo].[split](''' + @InteractionOrigins + ''','','')) '
	--IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_OPTIONAL_PART += 'AND CONCAT(AEP.[IdCampaign], ''_'', AEP.[ManagementResult]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) '
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'
	
	IF (@EvaluationTypes IS NOT NULL AND @EvaluationTypes != '') 
	BEGIN
		SET @FILTERS_OPTIONAL_PART += '
				AND EP.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationTypes + ''','',''))  '
	END;
	IF (@InteractionTags IS NOT NULL AND @InteractionTags != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [Tag] T (NOLOCK) 
				ON (T.[VCC] = ER.[Instance] 
					AND T.[Tag] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTags + ''','',''))) '
		SET @FILTERS_OPTIONAL_PART += '
				AND T.[AudioId] LIKE CONCAT(AEP.[IdInteraction], ''%'') 
				AND T.[AudioId] IS NOT NULL '
	END
	
	--IF (@InteractionFormats IS NOT NULL AND @InteractionFormats != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionFormat] IN (SELECT Value FROM [dbo].[split](''' + @InteractionFormats + ''','','')) '

	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
        SET @FILTERS_OPTIONAL_PART = ''
	    SET @FILTERS_EXCLUDING_PART += ' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
	END

	SET @SQL_EXTRA += '
			GROUP BY AEP.Completed,
						AEP.[StatusDescription],
						A.[ErrorMessage],
						AEP.score,
						AEP.IdAuditor,
						U.FirstName + '' '' + U.LastName,
						AEP.IdEvaluationPlan,
						EP.Description,
						EP.[Evaluation_Mode],
						AEP.idAgent,
						C.[AgentName],
						AEP.idInteraction,
						AEP.InteractionDate,
						AEP.InteractionType,
						AEP.IdCampaign, 
						E.[Type] '

	IF @InteractionCoached IS NOT NULL AND @InteractionCoached != ''
	BEGIN
		IF @InteractionCoached = 'true'
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) >= 1 '
		ELSE 
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) = 0 '
	END

	SET @SQL_EXTRA += '
			ORDER BY MAX(ER.EvaluationDate) DESC '

	SET @SQL_SELECT_1 += @SQL_FROM  + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA 

	-- SELECT @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)
	
END
GO
PRINT N'Modificando [dbo].[GetI6SyncInteractions]...';


GO
ALTER PROCEDURE [dbo].[GetI6SyncInteractions]
(
	@VCC					VARCHAR(50) = NULL,
	@IP						VARCHAR(50),						-- IP DEL SERVIDOR PARA LA BASE I6
	@Type					INT,								-- FLAG PARA INDICAR SI EL SERVIDOR I6 SE ENCUENTRA LOCAL O REMOTO
	@InteractionType		VARCHAR(50) = NULL,
	@StartDate				DATETIME = '1980-01-01T00:00:00',
    @EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@Campaigns				VARCHAR(MAX) = NULL,
 	@Agents					VARCHAR(MAX) = NULL,
	@DispositionCodes		VARCHAR(MAX) = NULL,
	@Origins				VARCHAR(MAX) = NULL,
	@MinDuration			INT = NULL,
	@MaxDuration			INT = NULL,
	@InteractionIds         VARCHAR(MAX) = NULL,
    @Evaluated              VARCHAR(MAX) = NULL,
	@UniqueIds				BIT = 0,							-- ESTE FLAG TIENE COMO PROPOSITO RETORNAR LA LISTA CONSOLIDAD POR IDS O EL TOTAL DEL LISTADO
	@ResultType				VARCHAR(50) = NULL					-- VARIABLE PARA DETERMINAR SI LA BUSQUEDA SERA SOBRE SOBRE DETALLES O ID (DETAILED, SUMMARIZED)
    
)
AS
BEGIN
	-- INFO: EN CHAT SE CREAN UN ID EN CADA INTERACCION(EJM: CHATS DE ATENCION EN LAS WEB DE BANCOS), LOS DEMAS CANALES ID + ENDDATE
	
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOS UNA VARIABLE PARA IDENTIFICAR SI EL SP ES LLAMADO DEL SISTEMA O POR OTRO SP
	DECLARE @IS_NESTED BIT = 0

	-- DECLARAMOASUN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
    DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''
	
	-- DECLARAMOS VARIABLES PARA NOS NOMBRES DE LAS TABLAS
	DECLARE @HISTORICAL_DATA_I6_BD NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_APPSTORE_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_CALL_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_CHAT_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_FACEBOOK_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_INSTAGRAM_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_MAIL_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_TWITTER_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_WEBCONTACT_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_WHATSAPP_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_YOUTUBE_TABLE NVARCHAR(100)

	-- DEFINIMOS EL NOMBRE DE LA BD
	SET @HISTORICAL_DATA_I6_BD = '[HistoricalDataI6_sq]' -- BD PARA DESARROLLO
	-- SET @HISTORICAL_DATA_I6_BD = '[HistoricalDataI6]'

	-- EL PARAMETRO TYPE DEFINE SI LA BD HISTORICALDATAI6 SE ENCUENTRA LOCAL O REMOTO
	IF (@Type = 0)  
	BEGIN  
		SET @HISTORICAL_DATA_I6_CALL_TABLE =			'[' + @Ip + ']' + '.' + @HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Call]'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @HISTORICAL_DATA_I6_CALL_TABLE =			@HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Call]'
	END  

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT += '
		SELECT '

	-- ARMAMOS LA PARTE BASE DE FILTROS
	SET @FILTERS_FIXED_PART = ' WHERE HDI6.[Vcc] = ''' + @VCC + ''''
	
	SET @FILTERS_OPTIONAL_PART  =' AND HDI6.[EndDate] BETWEEN '''
    SET @FILTERS_OPTIONAL_PART += (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) 
    SET @FILTERS_OPTIONAL_PART  +=''' AND '''  
    SET @FILTERS_OPTIONAL_PART  +=(SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' '
    

	-- DEPENDIENDO SI LA HORA DE FIN ES MAYOR A LA DE INICIO O NO DAMOS FORMA AL FILTRO DE HORA
	IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(HDI6.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' ';
	IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(HDI6.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' ';
		
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[Campaign] IN (SELECT VALUE FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	
	IF (@DispositionCodes IS NOT NULL AND @DispositionCodes != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(HDI6.[DispositionTreePath] IN (SELECT VALUE FROM [dbo].[split](''' + @DispositionCodes + ''','',''))) 
								OR
								(HDI6.[DispositionCode] IN (SELECT VALUE FROM [dbo].[split](''' + @DispositionCodes + ''','','')))
							)'

	-- ARMAMOS EL ORDER BY
	SET @SQL_EXTRA += 'ORDER BY [ID], [EndDate] DESC'

	IF (@InteractionType = 'CALL')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_CALL_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_CHAT
		SET @SQL_SELECT += '
								[Vcc]														''vcc'',
								[Id] + ''_0_0''												''ID'',
								[Id]														''InteractionId'',
								0															''Section'',
								0															''Part'',
								''CALL''													''Channel'',
								[ContactAddress]											''Number'', 
								''''														''Gender'',
								ISNULL([HoldTime], 0)										''SilenceTime'',
								ISNULL([AudioDuration], 0)									''DurationTime'', -- ESTO SE DEBE CORREGIR
								-- ISNULL([AttentionTime], 0)								''AttentionTime'', -- SE AGREGO CAMPO PARA AMBOS EXISTAN
								ISNULL([AudioDuration], [AttentionTime])					''AttentionTime'', -- SE AGREGO CAMPO PARA TOMAR EL TIEMPO TOTAL DE TODOS LOS PARTS
								ISNULL([AudioRecords], 1)									''TotalParts'',
								NULL														''Category1'',
								NULL														''Category2'',
								NULL														''Category3'',
								[DispositionTreePath]										''Description'',
								[DispositionCode]											''DispositionCode'',
								[Campaign]													''Campaign'',
								[LastAgent]													''Agent'',
								NULL														''agentName'',
								CASE [Initiative] WHEN ''INBOUND'' THEN ''E''
													WHEN ''Inb.'' THEN ''E''
													WHEN ''OUTBOUND'' THEN ''S''
													WHEN ''Out.'' THEN ''S''
													ELSE NULL END							''Type'',
								CONVERT(VARCHAR, [StartDate], 120)							''StartDate'',
								CONVERT(VARCHAR, [EndDate], 120)							''EndDate'',
								NULL														''Format'' '
								
		-- POR LAS RESTRICCIONES DE SPEECH, FILTRAMOS SOLO INTERACCIONES QUE TENGA ID AGENTE DIFERENTE DE NULL
		SET @FILTERS_FIXED_PART += 'AND [IsTaken] = 1 
									AND [AudioRecords] >= 1 '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[LastAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '

		-- PARA HACER EL FILTRO POR ORIGEN, REEMPLAZAMOS EN EL INPUT POR LOS VALORES DE LA TABLA
		IF (@Origins IS NOT NULL AND @Origins != '') 
		BEGIN
			SET @Origins = REPLACE(@Origins, 'E', 'INBOUND,Intb.')
			SET @Origins = REPLACE(@Origins, 'S', 'OUTBOUND,Out.')
			SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[Initiative] IN (SELECT VALUE FROM [dbo].[split](''' + @Origins + ''','','')) '
		END

		IF(@MinDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[AudioDuration] >= ' + (SELECT CONVERT(varchar(10), @MinDuration)) + ' '

		IF(@MaxDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[AudioDuration] <= ' + (SELECT CONVERT(varchar(10), @MaxDuration)) + ' '
	END 

	IF @InteractionIds IS NOT NULL AND @InteractionIds <> ''
    BEGIN
        SET @FILTERS_OPTIONAL_PART = '';
	    SET @FILTERS_EXCLUDING_PART=' AND ID IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) ';
    END
	-- AGREGAMOS EL CONTADOR DE FILAR AL SELECT
	SET @SQL_SELECT += '
								,RN = ROW_NUMBER() OVER(PARTITION BY [ID], CONVERT(VARCHAR, EndDate, 23) ORDER BY [EndDate] DESC) '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM ' + @HISTORICAL_DATA_I6_TABLE + ' HDI6 (NOLOCK) '

	-- UNIMOS LAS PARTES DEL QUERY
	SET @SQL_SELECT += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA
	
	-- VERIFICAMOS SI EXISTE LA TABLA TEMPORAL #TMP_HD_INTERACTIONS
	IF OBJECT_ID('TEMPDB..#TMP_HD_INTERACTIONS') IS NULL
	BEGIN
		-- CREAMOS UNA TABLA TEMPORAL PARA INSERTAR LOS REGISTROS DE LA HDI6
		CREATE TABLE #TMP_HD_INTERACTIONS
		(
			[VCC] VARCHAR(50), 
			[ID] VARCHAR(300),  
			[InteractionId] VARCHAR(250), 
			[Section] INT,
			[Part] INT,
			[Channel] VARCHAR(50), 
			[Number] VARCHAR(50), 
			[Gender] VARCHAR(50), 
			[SilenceTime] DECIMAL(10, 2),
			[DurationTime] DECIMAL(10, 2),
			[AttentionTime] DECIMAL(10, 2),
			[TotalParts] INT,
			[Category1] VARCHAR(50),
			[Category2] VARCHAR(50),
			[Category3] VARCHAR(50),
			[Description] VARCHAR(50),
			[DispositionCode] VARCHAR(250), 
			[Campaign] VARCHAR(50), 
			[Agent] VARCHAR(50), 
			[AgentName] VARCHAR(250), 
			[Type] VARCHAR(50), 
			[StartDate] VARCHAR(100),
			[EndDate] VARCHAR(100),
			[Format] VARCHAR(50),
			RN INT
		)

		-- REAFIRMAMOS QUE EL SP NO ESTA ANIDADO EN OTRO
		SET @IS_NESTED = 0

		-- PRINT 'SP NO ANIDADO'
	END
	ELSE
	BEGIN
		-- SI LA TABLA TEMPORAL YA EXISTIA, EL SP ESTA ANIDADO EN OTRO (P.E.: [dbo].[GetAsyncBillingInteractions])
		SET @IS_NESTED = 1

		-- PRINT 'SP ANIDADO'
	END 

	-- INSERTAMOS EL RESULTADO EN LA TABLA TEMPORAL
	INSERT INTO #TMP_HD_INTERACTIONS
		-- EJECUTAMOS LA CONSULTA
		EXEC (@SQL_SELECT)

	-- VARIABLES PARA TRABAJAR CON LA TABLA TEMPORAL AL FINAL DEL SP
    DECLARE @QUERY                  VARCHAR(MAX) = ''
    DECLARE @QUERY_FILTER           VARCHAR(MAX) = ''
    DECLARE @QUERY_JOIN             VARCHAR(MAX) = ''
	
	-- FILTRO POR INTERACCIONES EVALUADAS O NO
	IF (@Evaluated IS NOT NULL AND @Evaluated <> '')
	    BEGIN 
		DECLARE @EvaluatedTable TABLE (Val BIT)

		INSERT INTO @EvaluatedTable SELECT Value FROM [dbo].[split]( @Evaluated ,',')

		-- SOLAMENTE SI ES SI O NO
		IF ((SELECT COUNT(Val) FROM @EvaluatedTable) = 1 )
		BEGIN
			IF((SELECT Val FROM @EvaluatedTable WHERE Val = 1) IS NOT NULL) -- Si  es Si
			BEGIN 
				SET @QUERY_JOIN = ' JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) ON (AEP.[IdInteraction] = HDI.[id] AND AEP.[Completed]=1 ) '
			END
		ELSE  --Si es No
           BEGIN
               SET @QUERY_JOIN = ' LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) ON (AEP.[IdInteraction] = HDI.[id] AND AEP.[Completed]=1 ) '
               SET @QUERY_FILTER = ' AND AEP.[IdInteraction] IS NULL '
           END
       END
       
	 END
	-- FIN FILTRO INTERACCIONES EVALUADAS


	
	-- SI EL SP NO ESTA ANIDADO, HACEMOS SELECT AL RESULTADO A MOSTRAR
	IF @IS_NESTED = 0
	BEGIN
		-- HACEMOS EL SELECT SEGUN EL TIPO DE BUSQUEDA SETTEADO
		IF @UniqueIds = 1 -- ENFOCADO A INTERACCIONES
		BEGIN
			IF @ResultType = 'SUMMARIZED'
			BEGIN
				SET @QUERY = '
					SELECT HDI.[channel]										''interactionType'',
							COUNT(DISTINCT HDI.[id])							''interactions'',
							SUM(HDI.[totalParts])								''details'',
							SUM(HDI.[attentionTime])							''attentionTime''
						FROM #TMP_HD_INTERACTIONS HDI '
				SET @QUERY += @QUERY_JOIN
				SET @QUERY += ' WHERE HDI.[RN] = 1 ' + @QUERY_FILTER + ' GROUP BY HDI.[channel]'
				
			END
			ELSE IF @ResultType = 'DETAILED'
			BEGIN
				SET @QUERY = ' SELECT HDI.* FROM #TMP_HD_INTERACTIONS HDI ' + @QUERY_JOIN +  ' WHERE HDI.[RN] = 1 ' + @QUERY_FILTER
				/*
				SET @QUERY = '
					SELECT HDI.[vcc]											''vcc'',
							HDI.[channel]										''interactionType'',
							HDI.[campaign]										''campaign'',
							HDI.[id]											''id'',
							HDI.[firstTakedAgent]								''agent'',
							HDI.[initiative]									''origin''
						FROM #TMP_HD_INTERACTIONS HDI '
				SET @QUERY += @QUERY_JOIN
				
				SET @QUERY += ' WHERE HDI.[RN] = 1 ' + @QUERY_FILTER + '
					GROUP BY HDI.[vcc], HDI.[channel], HDI.[campaign], HDI.[id], HDI.[firstTakedAgent], HDI.[initiative]'
				*/
			END
			--EJECUTAR CONSULTA
			EXEC (@QUERY)
			
		END
		ELSE -- ENFOCADO A DETALLES
		BEGIN
			IF @ResultType = 'SUMMARIZED'
			BEGIN
			SET @QUERY = '
				SELECT HDI.[channel]											AS ''interactionType'',
						COUNT(DISTINCT HDI.[id])								AS ''interactions'',
						SUM(HDI.[totalParts])									AS ''details'',
						SUM(HDI.[attentionTime])							''attentionTime''
					FROM #TMP_HD_INTERACTIONS HDI '
			SET @QUERY += @QUERY_JOIN
			SET @QUERY += '	WHERE HDI.[RN] = 1 ' + @QUERY_FILTER + ' GROUP BY HDI.[channel] '
			
			END
			ELSE IF @ResultType = 'DETAILED'
			BEGIN
			    SET @QUERY = ' SELECT HDI.* FROM #TMP_HD_INTERACTIONS HDI ' + @QUERY_JOIN +  ' WHERE HDI.[RN] = 1 ' + @QUERY_FILTER
			END 
		-- EJECUTAR CONSULTA
		  EXEC (@QUERY)
		END
	END
END
GO
PRINT N'Modificando [dbo].[GetNotEvaluatedInteractionsAuditor]...';


GO
-- ESTE SP MUETRA LA LISTA DE EVALUACIONES PENDIENTES PARA UN AUDITOR
ALTER PROCEDURE [dbo].[GetNotEvaluatedInteractionsAuditor] (
	@Instance Varchar(50) = NULL, 
	@UserId Varchar(50) = NULL,
	@IdCampaigns VARCHAR(MAX) = NULL,
	@IdAgents Varchar(MAX) = NULL,
	@EvaluationPlans Varchar(MAX) = NULL,
	@InteractionTypes Varchar(100) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
 	@EvaluationDateTo   VARCHAR(MAX) = '2050-01-01T23:59:59',
	@EvaluationStatus BIT = 1,
 	@InteractionIds     VARCHAR(MAX) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @USER_ROLE VARCHAR(50) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''

	-- IDENTIFICAMOS EL ROL DEL USUARIO
	SELECT @USER_ROLE = U.[Role]
		FROM [dbo].[User] U (NOLOCK)
		WHERE U.[VCC] = @Instance
			AND U.[ID] = @UserId

	-- EMULAMOS UNA NUEVA TABLA EN BASE A AuditorEvaluationPlan DONDE SE REMOVERAN TODOS LOS REGISTROS DUPLICADOS PARA EL PK DE LA TABLA Audio
	SET @SQL_SELECT_1 += '
		WITH CTE AS (
			SELECT AEP.[Instance], 
					AEP.[IdEvaluationPlan], 
					AEP.[IdInteraction], 
					AEP.[IdAuditor], 
					AEP.[Score], 
					IEP.[AgentName],
					AEP.[LastModifiedDate],
					RN = ROW_NUMBER() OVER(PARTITION BY AEP.[Instance], AEP.[IdEvaluationPlan], AEP.[IdInteraction] ORDER BY AEP.[LastModifiedDate] DESC)
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance] 
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
					AND IEP.[IdAgent] = AEP.[IdAgent]
			WHERE AEP.[Instance] = ''' + @Instance + ''' 
				AND AEP.[Completed] = 0 
				AND AEP.[IdAuditor] <> ''SPEECH''
				AND AEP.[StatusDescription] NOT IN(''INVALID'') '

	IF @USER_ROLE = 'quality_auditor' 
	BEGIN
		SET @SQL_SELECT_1 += '
				AND	AEP.[IdAuditor] = ''' + @UserId + ''' '
	END

	IF (@IdCampaigns IS NOT NULL AND @IdCampaigns != '') SET @SQL_SELECT_1 += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaigns + ''','','')) ';
	IF (@IdAgents IS NOT NULL AND @IdAgents != '') SET @SQL_SELECT_1 += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgents + ''','','')) ';
	IF (@EvaluationPlans IS NOT NULL AND @EvaluationPlans != '') SET @SQL_SELECT_1 += 'AND AEP.[IdEvaluationPlan] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationPlans + ''','','')) '
	IF (@InteractionTypes IS NOT NULL AND @InteractionTypes != '') SET @SQL_SELECT_1 += 'AND AEP.[InteractionType] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTypes + ''','','')) ';
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @SQL_SELECT_1 += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'

	SET @SQL_SELECT_1 += '
		),
		CLEANED_CTE AS (
			SELECT C.[Instance], 
					C.[IdEvaluationPlan], 
					C.[IdInteraction], 
					C.[IdAuditor], 
					C.[Score], 
					C.[AgentName],
					C.[LastModifiedDate]
			FROM [CTE] C
			WHERE C.[RN] = 1
		) '
	-- EL CTE SOLO PUEDE SER INVOCADO UNA VEZ POR ESO LO PONEMOS EN EL SELECT FINAL DONDE EL CONTADOR(RN) ES 1
	
	-- ARMAMOS EL SELECT PRINCIPAL PARA LA BUSQUEDA DE EVALUACIONES PENDIENTES DEL AUDITOR
	SET @SQL_SELECT_1 += '
		SELECT DISTINCT '
	SET @SQL_SELECT_1 += '
				AEP.[IdInteraction]															''id'', 
				AEP.[IdCampaign]															''descriptionCampaign'',
				AEP.[IdAgent]																''idAgent'',
				AEP.[IdAgent]																''descriptionAgent'',
				AEP.[InteractionDate]														''dateIni'',
				AEP.[InteractionDateEnd]													''dateFin'',
				AEP.[InteractionDuration]													''interactionTime'',
				AEP.[Completed]																''evaluated'',
				AEP.[InteractionType]														''interactionType'',
				AEP.[ManagementResult]														''dispositionCode'',
				AEP.[ContactId]																''address'',
				AEP.[InteractionOrigin]														''origin'',
				AEP.[IdEvaluationPlan]														''idEvaluationPlan'',
				EP.[ProcessId]																''processId'',
				EP.[Description]															''descriptionEvaluationPlan'',
				EP.[DateFin]																''dateFinEvaluationPlan'', 
				EP.[Modality]																''evaluationPlanModality'',
				EP.[Evaluation_Mode]														''evaluationPlanEvaluationMode'',
				A.[ID]																		''idAuditor'', 
				A.[Description]																''descriptionAuditor'',
				ISNULL(U.[FirstName] + '' '', '''') + ISNULL(U.[LastName], '''')			''auditorName'',						-- NOMBRE DEL AUDITOR
				C.[AgentName]																''agentName'',							-- NOMBRE DEL AGENTE
				C.[IdAuditor]																''lastEvaluationEvaluator'', 
				C.[Score]																	''lastEvaluationScore'',
				AEP.[Status]																''status'',
				AEP.[StatusDescription]														''statusDescription'''

	SET @SQL_FROM += '
			FROM [AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = EP.Instance
					AND EP.[ID] = AEP.IdEvaluationPlan) 
			INNER JOIN CLEANED_CTE C (NOLOCK) 
				ON C.[Instance] = AEP.[Instance] 
					AND C.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
					AND C.[IdInteraction] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[User] U (NOLOCK)
				ON U.[VCC] = AEP.[Instance]
					AND U.[ID] = AEP.[IdAuditor]
			LEFT JOIN [Auditor] A (NOLOCK) 
				ON (A.[ID] = AEP.[IdAuditor]) '

	SET @FILTERS_FIXED_PART = '
			WHERE AEP.[Instance] = ''' + @Instance + ''' 
				AND AEP.[Completed] = 0
				AND AEP.[StatusDescription] NOT IN(''INVALID'')
				AND EP.[Enabled] = 1 
				AND (
					(EP.[Evaluation_Mode] = ''X'' AND EP.[Status] = 8)
					OR
					(EP.[Evaluation_Mode] = ''M'')
				) '

	-- AGREGAMOS EL FILTRO DE ESTADO
	IF @EvaluationStatus = 0
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND AEP.[Status] = 0 '
	END
	ELSE IF @EvaluationStatus = 1
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND AEP.[Status] = 1 '
	END

	-- HACEMOS EL FILTRADO SEGUN EL ROL DEL USUARIO
	IF @USER_ROLE = 'quality_auditor'
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND	AEP.[IdAuditor] = ''' + @UserId + ''' '
	END
	ELSE IF @USER_ROLE = 'administrator' OR @USER_ROLE = 'quality_admin'
	BEGIN
		SET @FILTERS_FIXED_PART += ''
	END
	ELSE 
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND	AEP.[IdAuditor] = ''' + @UserId + ''' '
	END

	/*
	IF (@IdCampaigns IS NOT NULL AND @IdCampaigns != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaigns + ''','','')) ';
	IF (@IdAgents IS NOT NULL AND @IdAgents != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgents + ''','','')) ';
	--IF (@EvaluationPlans IS NOT NULL AND @EvaluationPlans != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdEvaluationPlan] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationPlans + ''','','')) '
	IF (@InteractionTypes IS NOT NULL AND @InteractionTypes != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionType] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTypes + ''','','')) ';
	-- IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_EXCLUDING_PART += 'AND CONCAT(AEP.[IdCampaign], ''_'', AEP.[ManagementResult]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) ';
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'
	*/
	IF (@EvaluationDateTo IS NOT NULL AND @EvaluationDateTo != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[DateFin] <= ''' + @EvaluationDateTo + '''  ';
	
	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
       BEGIN 
            SET @FILTERS_OPTIONAL_PART = '';
	        SET @FILTERS_EXCLUDING_PART=' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) ';
       END

	SET @SQL_SELECT_1 += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART;

	--SELECT @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)

 	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetProcesses]...';


GO
-- GetProcesses 'inconcert', 'name', '', NULL, NULL, 'SPEECH'
ALTER PROCEDURE [dbo].[GetProcesses]
(
	@VCC						VARCHAR(50) = NULL,
	@SearchCriteria				VARCHAR(50) = NULL,
	@SearchExpression			VARCHAR(50) = NULL,
	@StartDate					DATETIME,
	@EndDate					DATETIME,
	@Type						VARCHAR(50)
)
AS
BEGIN
	DECLARE @SQL NVARCHAR(MAX)
	SET @SQL = '
	SET NOCOUNT ON

	SELECT [VCC]																				''vcc'',
			[Name]																				''name'',
			[Description]																		''description'',
			[ClientId]																			''clientId'',
			[Percentage]																		''percentage'',
			[StatusDescription]																	''statusDescription'',
			(CASE WHEN [Status] IS NULL THEN ''UNKNOWN'' ELSE [Status] END)						''status'',
			[StartDate]																			''startDate'',
			[EndDate]																			''endDate'',
			[MinDurationTime]																	''minDurationTime'',
			[MaxDurationTime]																	''maxDurationTime'',
			[Language]																			''language'',
			[Environment]																		''environment'',
			[BatchScheduleId]																	''batchScheduleId'',
			[CreatedDate]																		''createdDate'',
			[CreatedByUserId]																	''createdByUserId'',
			[LastModifiedDate]																	''lastModifiedDate'',
			[LastModifiedByUserId]																''lastModifiedByUserId''
		FROM [Process] (NOLOCK)
		WHERE [VCC] = ''' + @VCC + '''
			AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
			AND ISNULL([Description], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''description'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
			AND ISNULL([ClientId], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''clientId'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
			AND ISNULL([Status], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''status'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
			AND ISNULL([Environment], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''environment'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END'

	IF(@StartDate IS NOT NULL AND @EndDate IS NOT NULL)
	BEGIN
		SET @SQL += '
			AND [CreatedDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
		'
	END
	SET @SQL += '
			AND [Type] = ''' + @Type + '''
	ORDER BY [Status] desc, [CreatedDate] desc 

	SET NOCOUNT OFF
	'
	EXEC(@SQL)
END
GO
PRINT N'Modificando [dbo].[SaveEvaluationReview]...';


GO
ALTER PROCEDURE [dbo].[SaveEvaluationReview] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@Review VARCHAR(500) = NULL,
	@SaveUserId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- ACTUALIZAMOS EL REGISTRO CORRESPONDIENTE A LA REVISION
	UPDATE [dbo].[EvaluationReview]
		SET [Review] = @Review,
			[LastModifiedDate] = GETUTCDATE(),
			[LastModifiedUserId] = @SaveUserId,
			[Timestamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [EvaluationPlanId] = @EvaluationPlanId
			AND [InteractionId] = @InteractionId
			AND [SupervisorId] = @SupervisorId

	-- SI NO SE ACTUALIZO NINGUN REGISTRO, LO INSERTAMOS
	IF @@ROWCOUNT = 0
	BEGIN
		-- 
		INSERT INTO [dbo].[EvaluationReview] (
				[VCC],
				[EvaluationPlanId],
				[InteractionId],
				[SupervisorId],
				[Review],
				[CreatedDate],
				[CreatedUserId],
				[Timestamp]
			) VALUES (
				@VCC,
				@EvaluationPlanId,
				@InteractionId,
				@SupervisorId,
				@Review,
				GETUTCDATE(),
				@SaveUserId,
				GETUTCDATE()
			)
	END

	-- RETORNAMOS EL REGISTRO INSERTADO/ACTUALIZADO
    SELECT ER.[VCC]													'vcc',
			ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[InteractionId]										'interactionId',
			ER.[SupervisorId]										'supervisorId',
			ER.[Review]												'review'
		FROM [dbo].[EvaluationReview] ER (NOLOCK) 
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])
	
	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[RestoreEvaluationResultDraftBackup]...';


GO
CREATE PROCEDURE [dbo].[RestoreEvaluationResultDraftBackup] (
	@VCC VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@AuditorId VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON
	-- EL PRESENTE SP TIENE LA FINALIDAD DE ELIMINAR LOS REGISTROS DE RESPALDO PARA BORRADOR

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        
		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- ELIMINAMOS LOS RESULTS DE LA EVALUACION
		DELETE FROM [dbo].[EvaluationResult]
			WHERE [Instance] = @VCC
				AND [IdEvaluationPlan] = @EvaluationPlanId
				AND [IdInteraction] = @InteractionId
				AND [IdAuditor] = @AuditorId

		-- DECLARAMOS UNA VARIABLE PARA VERIFICAR EL TIPO DEL PLAN
		DECLARE @IS_MIXED_EVALUATION_PLAN BIT = 0

		-- VERIFICAMOS QUE EL PLAN DE EVALUACION ES DEL TIPO MIXTO
		SELECT @IS_MIXED_EVALUATION_PLAN = IIF (EP.[Evaluation_Mode] = 'X', 1, 0) 
			FROM [dbo].[EvaluationPlan] EP (NOLOCK) 
			WHERE EP.[Instance] = @VCC
				AND EP.[ID] = @EvaluationPlanId

		-- DECLARAMOS UNA VARIABLE PARA VERIFICAR SI LA AUDITORIA YA ESTA GUARDADA COMO BORRADOR
		DECLARE @EXISTS_DRAFT_DATA BIT = 0

		IF EXISTS (
			SELECT 1 
				FROM [dbo].[EvaluationResult] (NOLOCK)
				WHERE [Instance] = @VCC
					AND [IdEvaluationPlan] = @EvaluationPlanId
					AND [IdInteraction] = @InteractionId
					AND [IdEvaluator] = 'SPEECH'
					AND [IdAuditor] = @AuditorId + '-DRAFT'
		)
			SET @EXISTS_DRAFT_DATA = 1

		IF @IS_MIXED_EVALUATION_PLAN = 1 AND @EXISTS_DRAFT_DATA = 1
		BEGIN
			-- RESTAURAMOS LOS RESULTADOS DE LA PARTE AUTOMATICA
			UPDATE [dbo].[EvaluationResult]
				SET [IdAuditor] = @AuditorId
				WHERE [Instance] = @VCC
					AND [IdEvaluationPlan] = @EvaluationPlanId
					AND [IdInteraction] = @InteractionId
					AND [IdEvaluator] = 'SPEECH'
					AND [IdAuditor] = @AuditorId + '-DRAFT'
		END 

		-- ACTUALIZAMOS EL ESTADO DE LA AUDITORIA
		UPDATE [dbo].[AuditorEvaluationPlan] 
			SET [StatusDescription] = 'PENDING'
			WHERE [Instance] = @VCC
				AND [IdEvaluationPlan] = @EvaluationPlanId
				AND [IdInteraction] = @InteractionId
				AND [IdAuditor] = @AuditorId 

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
	
	
    SET NOCOUNT OFF
END
GO
PRINT N'Actualizando [dbo].[DeleteBatchSchedule]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteBatchSchedule]';


GO
PRINT N'Actualizando [dbo].[FinishedBatchClose]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[FinishedBatchClose]';


GO
PRINT N'Actualizando [dbo].[SaveBatchScheduleExecution]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveBatchScheduleExecution]';


GO
PRINT N'Actualizando [dbo].[DeleteBatchScheduleExecution]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteBatchScheduleExecution]';


GO
PRINT N'Actualización completada.';


GO
