PRINT N'Modificando [dbo].[GetBatchScheduledTemplateItemResults]...';


GO
ALTER PROCEDURE [dbo].[GetBatchScheduledTemplateItemResults]
(
	@VCC					VARCHAR(50) = NULL,
	@BatchScheduledId		VARCHAR(50) = NULL,
	@StartDate				DATETIME = NULL, -- FILTRO PARA LOS RESULATDOS RECIENTES
	@EndDate				DATETIME = NULL, -- FILTRO PARA LOS RESULATDOS RECIENTES
	@Category1				VARCHAR(50) = NULL,
	@Category2				VARCHAR(50) = NULL,
	@Description			VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- OBTENEMOS LOS RESULTADOS RELACIONADOS CON EL ITEM DE LA AGENDA
	;WITH CTE AS (
		SELECT --SRD.[VCC]								'vcc',
				S.[BatchScheduleId]						'batchScheduleId',
				HTT.[Description]						'description',
				SRD.[StudyId]							'studyId',
				S.[ProcessId]							'processId',
				SRD.[TranscriptionId]					'transcriptionId',
				IIF (PAI.[InteractionType] IS NULL, 
						'CALL', 
						PAI.[InteractionType]
				)										'interactionType',
				IIF (PAI.[InteractionType] IS NULL, 
						PA.[AudioId],
						PAI.[InteractionId]
				)										'id',
				PA.[Section]							'section',
				PA.[Part]								'part',
				PAI.[Campaign]							'campaign',
				PAI.[FormattedEndDate]					'folder',
				-- RN = ROW_NUMBER() OVER(PARTITION BY IIF (PAI.[InteractionType] IS NULL, PA.[AudioId], PAI.[InteractionId]), PA.[Section], PA.[Part], PAI.[Campaign], PAI.[FormattedEndDate] ORDER BY S.[CreatedDate] desc)
				RN = ROW_NUMBER() OVER(PARTITION BY SRD.[TranscriptionId] ORDER BY S.[CreatedDate] desc)
			FROM [dbo].[StudyResultSummaryDetail] SRD (NOLOCK)
			INNER JOIN [dbo].[Study] S (nolock)
				ON S.[VCC] = SRD.[VCC]
					AND S.[Name] = SRD.[StudyId]
			LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK)
				ON PA.[VCC] = SRD.[VCC] 
					AND PA.[ProcessId] = S.[ProcessId] 
					AND CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part]) = SRD.[TranscriptionId]
			LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
				ON PAI.[VCC] = SRD.[VCC]
					AND PAI.[ProcessId] = S.[ProcessId]
					AND CONCAT(PAI.[InteractionType], '_', PAI.[Campaign], '_', PAI.[FormattedEndDate], '_', PAI.[InteractionId]) = SRD.[TranscriptionId]
			INNER JOIN [dbo].[HistoricTemplateTheme] HTT (NOLOCK)
				ON HTT.[VCC] = SRD.[VCC]
					AND HTT.[StudyId] = SRD.[StudyId]
					AND HTT.[ID] = SRD.[TemplateThemeId]
			WHERE S.[VCC] = @VCC
				AND S.[BatchScheduleId] = @BatchScheduledId
				AND SRD.[CreatedDate] BETWEEN @StartDate AND @EndDate
				AND (
					HTT.[Category1] = @Category1
					OR (
						HTT.[Category1] IS NULL
						AND 
						@Category1 IS NULL
					)
				)
				AND (
					HTT.[Category2] = @Category2
					OR (
						HTT.[Category2] IS NULL
						AND
						@Category2 IS NULL
					)
				)
				AND HTT.[Description] = @Description
			-- GROUP BY SRD.[VCC], SRD.[StudyId], S.[ProcessId], SRD.[TranscriptionId], PAI.[InteractionType], PA.[AudioId], PAI.[InteractionId]
			
	)
	SELECT * FROM CTE WHERE [RN] = 1 ORDER BY [TranscriptionId]

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetBatchScheduledTemplateResults]...';


GO
ALTER PROCEDURE [dbo].[GetBatchScheduledTemplateResults]
(
	@VCC					VARCHAR(50) = NULL,
	@BatchScheduledIds		VARCHAR(MAX) = NULL,
	@StartDate				DATETIME = NULL, -- FILTRO PARA LOS RESULATDOS RECIENTES
	@EndDate				DATETIME = NULL -- FILTRO PARA LOS RESULATDOS RECIENTES
)
AS
BEGIN
	SET NOCOUNT ON

	--DECLARE @VCC VARCHAR(50) = NULL, @BatchScheduleId VARCHAR(50) = NULL
	--SET @VCC = 'vccocc'
	--SET @BatchScheduleId = '20211230_niveles'

	-- OBTENEMOS LOS RESULTADOS RELACIONADOS CON LA AGENDA
	SELECT SRD.[VCC]								'vcc',
			S.[BatchScheduleId]						'batchScheduleId',
			--SRD.[StudyId]							'studyId',
			HTT.[TemplateId]						'templateId',
			SRD.[TemplateThemeId]					'templateThemeId',
			HTT.[Category1]							'category1',
			HTT.[Category2]							'category2',
			HTT.[Description]						'description',
			SRD.[TemplateThemeItemId]				'templateThemeItemId',
			SRD.[TranscriptionId]					'transcriptionId',
			COUNT(*)								'ocurrencies',
			COUNT(
				CASE WHEN SRD.[CreatedDate] >= @StartDate THEN 1 ELSE NULL END
			)										'latestOcurrencies'
		FROM [dbo].[StudyResultSummaryDetail] SRD (NOLOCK)
		INNER JOIN [dbo].[Study] S (nolock)
			ON S.[VCC] = SRD.[VCC]
				AND S.[Name] = SRD.[StudyId]
		INNER JOIN [dbo].[HistoricTemplateTheme] HTT (NOLOCK)
			ON HTT.[VCC] = SRD.[VCC]
				AND HTT.[StudyId] = SRD.[StudyId]
				AND HTT.[ID] = SRD.[TemplateThemeId]
		WHERE S.[VCC] = @VCC
			AND SRD.[CreatedDate] BETWEEN @StartDate AND @EndDate
			AND (
				(
					@BatchScheduledIds <> ''
					AND
					S.[BatchScheduleId] IN (SELECT VALUE FROM [dbo].[split](@BatchScheduledIds, ','))
				)
				OR 
				(
					@BatchScheduledIds = ''
					AND 
					S.[BatchScheduleId] IS NOT NULL
				)
			)
		GROUP BY SRD.[VCC],
					S.[BatchScheduleId],
					--SRD.[StudyId],
					HTT.[TemplateId],
					SRD.[TemplateThemeId],
					HTT.[Category1],
					HTT.[Category2],
					HTT.[Description],
					SRD.[TemplateThemeItemId],
					SRD.[TranscriptionId]
	
	/*
	-- OBTENEMOS LOS RESULTADOS RECIENTES
	SELECT SRD.[VCC]								'vcc',
			S.[BatchScheduleId]						'batchScheduleId',
			SRD.[StudyId]							'studyId',
			HTT.[TemplateId]						'templateId',
			SRD.[TemplateThemeId]					'templateThemeId',
			HTT.[Category1]							'category1',
			HTT.[Category2]							'category2',
			HTT.[Description]						'description',
			SRD.[TemplateThemeItemId]				'templateThemeItemId',
			SRD.[TranscriptionId]					'transcriptionId',
			SRD.[CreatedDate]						'createdDate'
		FROM [dbo].[StudyResultSummaryDetail] SRD (NOLOCK)
		INNER JOIN [dbo].[Study] S (nolock)
			ON S.[VCC] = SRD.[VCC]
				AND S.[Name] = SRD.[StudyId]
		INNER JOIN [dbo].[HistoricTemplateTheme] HTT (NOLOCK)
			ON HTT.[VCC] = SRD.[VCC]
				AND HTT.[StudyId] = SRD.[StudyId]
				AND HTT.[ID] = SRD.[TemplateThemeId]
		WHERE S.[VCC] = @VCC
			AND (
				(
					@BatchScheduleId IS NOT NULL
					AND
					S.[BatchScheduleId] = @BatchScheduleId 
				)
				OR 
				(
					@BatchScheduleId IS NULL
					AND 
					S.[BatchScheduleId] IS NOT NULL
				)
			)
			AND SRD.[CreatedDate] >= @StartDate
	*/

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluations]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluations] (
	@Instance Varchar(50) = NULL,
	@IdAuditor VARCHAR(MAX) = NULL,
	@IdAgent Varchar(MAX) = NULL,
   	@IdCampaign VARCHAR(MAX) = NULL,
	@IdEvaluationPlan VARCHAR(MAX) = NULL,
 	@EvaluationDateFrom VARCHAR(50) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(50) = '2050-01-01T23:59:59',
	@EvaluationHourFrom VARCHAR(50) = '00:00:00',
    @EvaluationHourTo VARCHAR(50) = '23:59:59',
	@InteractionMinDuration Int = 0,
    @InteractionMaxDuration Int = 86400,
    @InteractionOrigins Varchar(50) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@EvaluationTypes Varchar(MAX) = NULL,
	@InteractionTags Varchar(MAX) = NULL,
	@InteractionFormats Varchar(50) = NULL,
	@InteractionCoached VARCHAR(50) = NULL,
	@InteractionIds     VARCHAR(MAX) = NULL,
	@EvaluationsLimit Int = 0,
	@ContactAddress Varchar(300) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	IF (@EvaluationHourFrom = '') SET @EvaluationHourFrom = '00:00:00';
	IF (@EvaluationHourTo = '') SET @EvaluationHourTo = '23:59:59';
	
	-- SI ORIGINS TIENE DOS VALORES, IGNORAMOS EL FILTRO
	IF (SELECT COUNT(*) FROM [dbo].[split](@InteractionOrigins, ',')) = 2 SET @InteractionOrigins = ''
	
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	-- EMULAMOS UNA NUEVA TABLA EN BASE A INTERACTIONEVALUATIONPLAN
	SET @SQL_SELECT_1 += '
		;WITH CTE AS (
			SELECT ER.[Instance],
					ER.[IdEvaluationPlan],
					ER.[IdInteraction], 
					ER.[IdAgent],
					IEP.[AgentName],
					RN = ROW_NUMBER() OVER(PARTITION BY IEP.[Instance], IEP.[IdEvaluationPlan], IEP.[IdInteraction] ORDER BY IEP.[CreatedDate] ASC)
				FROM [dbo].[EvaluationResult] ER (NOLOCK) 
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = ER.[Instance]
						AND EP.[Id] =  ER.[IdEvaluationPlan]
				INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
					ON (AEP.[Instance] = ER.[Instance] 
						AND AEP.[IdAuditor] = ER.[IdAuditor] 
						AND AEP.[IdInteraction] = ER.[IdInteraction] 
						AND AEP.[InteractionType] = ER.[InteractionType] 
						AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
				INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
					ON IEP.[Instance] = ER.[Instance] 
						AND IEP.[IdEvaluationPlan] = EP.[ID]
						AND IEP.[IdInteraction] = ER.[IdInteraction]
						AND IEP.[IdAgent] = ER.[IdAgent]
				WHERE ER.[Instance] = ''' + @Instance + '''
					AND ER.[EvaluationDate] BETWEEN ''' + @EvaluationDateFrom + '''AND ''' + @EvaluationDateTo + '''
					AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
					AND AEP.[Completed] = 1
		),
		SUMMARIZED_CTE AS (
			SELECT [Instance],
					[IdEvaluationPlan],
					[IdInteraction], 
					[IdAgent],
					[AgentName]
				FROM CTE
				WHERE RN = 1
		) '

	SET @SQL_SELECT_1 += '
		SELECT '

	SET @SQL_SELECT_1 += '
				AEP.Completed						''completed'',
				AEP.[StatusDescription]             ''statusDescription'',
				A.[ErrorMessage]                    ''errorMessage'',
    			AEP.score							''qualification'',
    			AEP.IdAuditor						''idAuditor'',
    			U.FirstName + '' '' + U.LastName	''auditorName'',
    			MAX(ER.EvaluationDate)				''evaluationDate'',
    			AEP.IdEvaluationPlan				''idEvaluationPlan'',
				EP.Description						''evaluationPlan'',
				EP.[Evaluation_Mode]				''evaluationType'',
    			AEP.idAgent							''idAgent'',
    			C.[AgentName]						''agentName'',							-- NOMBRE DEL AGENTE
				AEP.idInteraction					''idInteraction'',
				AEP.InteractionDate					''interactionDate'',
    			AEP.InteractionType					''interactionType'',
    			AEP.IdCampaign						''idCampaign'',
				E.[Type]							''environmentType'',
				IIF (
					ERV.[InteractionId] IS NULL,
					CAST(0 AS BIT),
					CAST(1 AS BIT)
				)									''review'',
				COUNT(ERC.[Id])						''commitments'' '

	SET @SQL_FROM += '
			FROM EvaluationResult ER (NOLOCK) 
			INNER JOIN SUMMARIZED_CTE C (NOLOCK) 
				ON C.[Instance] = ER.[Instance]
					AND C.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
					AND C.[IdInteraction] = ER.[IdInteraction] 
					AND C.[IdAgent] = ER.[IdAgent] 
			LEFT JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = ER.[Instance] 
					AND EP.[ID] = ER.IdEvaluationPlan) 
			LEFT JOIN [AuditorEvaluationPlan] AEP (NOLOCK) 
				ON (AEP.[Instance] = ER.[Instance] 
					AND AEP.[IdAuditor] = ER.[IdAuditor] 
					AND AEP.[IdInteraction] = ER.[IdInteraction] 
					AND AEP.[InteractionType] = ER.[InteractionType] 
					AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
			LEFT JOIN [dbo].[EvaluationReview] ERV (NOLOCK)
				ON ERV.[VCC] = AEP.[Instance]
					AND ERV.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERV.[InteractionId] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[EvaluationReviewCommitment] ERC (NOLOCK)
				ON ERC.[VCC] = AEP.[Instance] 
					AND ERC.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERC.[InteractionId] = AEP.[IdInteraction]
					-- AND ERC.[SupervisorId] = AEP.[IdAuditor] 
					AND ERC.[AgentId] = AEP.[idAgent]
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
			    ON A.[VCC] = AEP.[Instance]
			        AND A.[ID] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[Environment] E (NOLOCK)
				ON E.[VCC] = ER.[Instance]
					AND E.[Name] = EP.[EnvironmentId]
			LEFT JOIN [User] U (NOLOCK) 
				ON (U.[VCC] = ER.[Instance] 
					AND U.ID = AEP.IdAuditor) '

	SET @FILTERS_FIXED_PART = '
			WHERE ER.[Instance] = ''' + @Instance + '''
				AND ER.[EvaluationDate] >= ''' + @EvaluationDateFrom + '''
				AND ER.[EvaluationDate] <= ''' + @EvaluationDateTo + '''
				AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
				AND AEP.[Completed] = 1 ' -- LINEA PARA FILTRAR EVALUACIONES COMPLETADAS

	IF (@IdAuditor IS NOT NULL AND @IdAuditor != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAuditor] IN (SELECT Value FROM [dbo].[split](''' + @IdAuditor + ''','','')) '
	IF (@IdAgent IS NOT NULL AND @IdAgent != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgent + ''','','')) '
	IF (@IdCampaign IS NOT NULL AND @IdCampaign != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaign + ''','','')) '
	IF (@IdEvaluationPlan IS NOT NULL AND @IdEvaluationPlan != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[ID] IN (SELECT Value FROM [dbo].[split](''' + @IdEvaluationPlan + ''','','')) '
	IF (CAST(@EvaluationHourFrom AS TIME) <= CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) BETWEEN ''' + @EvaluationHourFrom + ''' AND ''' + @EvaluationHourTo + ''' '
	IF (CAST(@EvaluationHourFrom AS TIME) > CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) NOT BETWEEN ''' + @EvaluationHourTo + ''' AND ''' + @EvaluationHourFrom + ''' '
	IF (@InteractionMinDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] >= ' + (SELECT CONVERT(varchar(10), @InteractionMinDuration)) + ' '
	IF (@InteractionMaxDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] <= ' + (SELECT CONVERT(varchar(10), @InteractionMaxDuration))+ ' '
	IF (@InteractionOrigins IS NOT NULL AND @InteractionOrigins != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionOrigin] IN (SELECT Value FROM [dbo].[split](''' + @InteractionOrigins + ''','','')) '
	--IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_OPTIONAL_PART += 'AND CONCAT(AEP.[IdCampaign], ''_'', AEP.[ManagementResult]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) '
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'
	
	IF (@EvaluationTypes IS NOT NULL AND @EvaluationTypes != '') 
	BEGIN
		SET @FILTERS_OPTIONAL_PART += '
				AND EP.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationTypes + ''','',''))  '
	END

	IF(@ContactAddress <> '')
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND AEP.[ContactAddress] LIKE ''%' + @ContactAddress + '%''
			'
	END	
	
	IF (@InteractionTags IS NOT NULL AND @InteractionTags != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [Tag] T (NOLOCK) 
				ON (T.[VCC] = ER.[Instance] 
					AND T.[Tag] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTags + ''','',''))) '
		SET @FILTERS_OPTIONAL_PART += '
				AND T.[AudioId] LIKE CONCAT(AEP.[IdInteraction], ''%'') 
				AND T.[AudioId] IS NOT NULL '
	END
	
	--IF (@InteractionFormats IS NOT NULL AND @InteractionFormats != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionFormat] IN (SELECT Value FROM [dbo].[split](''' + @InteractionFormats + ''','','')) '

	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
        SET @FILTERS_OPTIONAL_PART = ''
	    SET @FILTERS_EXCLUDING_PART += ' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
	END

	SET @SQL_EXTRA += '
			GROUP BY AEP.Completed,
						AEP.[StatusDescription],
						A.[ErrorMessage],
						AEP.score,
						AEP.IdAuditor,
						U.FirstName + '' '' + U.LastName,
						AEP.IdEvaluationPlan,
						EP.Description,
						EP.[Evaluation_Mode],
						AEP.idAgent,
						C.[AgentName],
						AEP.idInteraction,
						AEP.InteractionDate,
						AEP.InteractionType,
						AEP.IdCampaign, 
						E.[Type],
						ERV.[InteractionId]'

	IF @InteractionCoached IS NOT NULL AND @InteractionCoached != ''
	BEGIN
		IF @InteractionCoached = 'true'
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) >= 1 '
		ELSE 
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) = 0 '
	END

	SET @SQL_EXTRA += '
			ORDER BY MAX(ER.EvaluationDate) DESC '

	SET @SQL_SELECT_1 += @SQL_FROM  + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA 

	-- SELECT @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)
	
END
GO
PRINT N'Creando [dbo].[GetCognitiveAnalysisProcessValidDurationTime]...';


GO
CREATE  PROCEDURE [dbo].[GetCognitiveAnalysisProcessValidDurationTime](
	@VCC VARCHAR(50) = NULL,
	@ProcessId VARCHAR(50)
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE RETORNAR LA CANTIDAD DE SEGUNDOS DE TRANSCRIPCION DE AUDIO CORRESPONDIENTE A UN PROCESS
	SET XACT_ABORT, NOCOUNT ON
	
	SELECT P.[Name] 'name',
			SUM(A.[DurationLinguisticTime]) 'validDurationTime'
		FROM Process P (NOLOCK)
		LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
			ON PA.[ProcessId] = P.[Name]
		LEFT JOIN [dbo].[Audio] A (NOLOCK) 
			ON A.[ID] = PA.[AudioId]
				AND A.[Section] = PA.[Section]
				AND A.[Part] = PA.[Part]
		WHERE P.[VCC] = @VCC 
			AND P.[Name] = @ProcessId
		GROUP BY P.[Name] 

	SET XACT_ABORT, NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[GetEvaluationResultsByCriteria]...';


GO
CREATE PROCEDURE [dbo].[GetEvaluationResultsByCriteria] (
	--@VCC VARCHAR(50) = NULL,
	@InteractionStartDate				DATETIME = '1980-01-01T00:00:00',
    @InteractionEndDate					DATETIME = '2050-01-01T23:59:59',
	@EvaluationPlanId					VARCHAR(50) = NULL,
	@AgentIds							VARCHAR(MAX) = NULL,
	@OKAbilities						VARCHAR(MAX) = NULL, -- SETTEAR ALL PARA "TODOS HABILIDADES CUMPLEN"
	@KOAbilities						VARCHAR(MAX) = NULL -- SETTEAR ALL PARA "TODOS HABILIDADES NO CUMPLEN"
)
AS
BEGIN
	SET NOCOUNT ON

	-- VALIDAMOS LA DATA NECESARIA
	IF @EvaluationPlanId IS NULL OR @EvaluationPlanId = '' RAISERROR('DATABASE_ERROR_OK_EVALUATION_PLAN_ID_NOT_RECEIVED', 16, 16)
	IF @OKAbilities = 'ALL'
	-- ISNULL(LEN(@OKAbilities), 0) = 0
	BEGIN
		SELECT @OKAbilities = STUFF(
					(
						SELECT DISTINCT ',' + HA.[Title] 
							FROM [dbo].[HistoricAbilityEvaluationFormat] HAEF (NOLOCK)
							INNER JOIN [dbo].[HistoricAbility] HA (NOLOCK)
								ON HA.[VCC] = HAEF.[VCC]
									AND HA.[EvaluationPlanId] = [HAEF].[EvaluationPlanId]
									AND HA.[ID] = HAEF.[IdAbility]
							WHERE [HAEF].[EvaluationPlanId] = @EvaluationPlanId
						FOR XML PATH(''), TYPE
					).value('.', 'NVARCHAR(MAX)'), 
					1, 
					1, 
					''
		)
	END
	
	IF @KOAbilities = 'ALL'
	-- IF ISNULL(LEN(@KOAbilities), 0) = 0
	BEGIN
		SELECT @KOAbilities = STUFF(
					(
						SELECT DISTINCT ',' + HA.[Title]  
							FROM [dbo].[HistoricAbilityEvaluationFormat] HAEF (NOLOCK)
							INNER JOIN [dbo].[HistoricAbility] HA (NOLOCK)
								ON HA.[VCC] = HAEF.[VCC]
									AND HA.[EvaluationPlanId] = [HAEF].[EvaluationPlanId]
									AND HA.[ID] = HAEF.[IdAbility]
							WHERE [HAEF].[EvaluationPlanId] = @EvaluationPlanId
						FOR XML PATH(''), TYPE
					).value('.', 'NVARCHAR(MAX)'), 
					1, 
					1, 
					''
		)
	END

	-- DECLARAMOS VARIABLES PARA DATA DE HABILIDADES
	DECLARE @TOTAL_ABILITIES INT = 0
	DECLARE @TOTAL_OK_ABILITIES INT = 0
	DECLARE @TOTAL_KO_ABILITIES INT = 0
	
	-- OBTENMOS LOS VALORES
	If @OKAbilities = '' SET @TOTAL_OK_ABILITIES = 0 ELSE SELECT @TOTAL_OK_ABILITIES = COUNT(Value) FROM [dbo].[split](@OKAbilities,',')
	If @KOAbilities = '' SET @TOTAL_KO_ABILITIES = 0 ELSE SELECT @TOTAL_KO_ABILITIES = COUNT(Value) FROM [dbo].[split](@KOAbilities,',')
	SET @TOTAL_ABILITIES = @TOTAL_OK_ABILITIES + @TOTAL_KO_ABILITIES

	;WITH RAW_RESULTS_CTE AS (
		SELECT ER.* 
			FROM [dbo].[EvaluationResult] ER (NOLOCK) 
			INNER JOIN [dbo].[Ability] A (NOLOCK)
				ON A.[Instance] =  ER.[Instance]
					AND A.[ID] = ER.IdAbility
			WHERE ER.[Instance] = 'bbva'
				AND ER.[IdEvaluationPlan] = @EvaluationPlanId
				AND ER.[InteractionDateFin] BETWEEN @InteractionStartDate AND @InteractionEndDate
				AND (
					(
						ISNULL(LEN(@AgentIds), 0) <> 0
						AND
						ER.[IdAgent] IN (SELECT Value FROM [dbo].[split](@AgentIds,','))
					)
					OR
					(
						ISNULL(LEN(@AgentIds), 0) = 0
					)
				)
				AND (
					(
						-- RETORNA LAS INTERACCIONES QUE TIENEN 100 EN LAS HABILIDADES OK
						ISNULL(LEN(@OKAbilities), 0) <> 0
						AND 
						A.[Title] IN (SELECT Value FROM [dbo].[split](@OKAbilities,','))
						AND 
						ER.[AbilityInnerScore] = 100
					)
					OR
					(
						ISNULL(LEN(@KOAbilities), 0) <> 0
						AND 
						A.[Title] IN (SELECT Value FROM [dbo].[split](@KOAbilities,','))
						AND 
						ER.[AbilityInnerScore] = 0
					)
				)
	),
	FILTERED_RESULTS_CTE AS (
		SELECT * ,
				RN = ROW_NUMBER() OVER(PARTITION BY [IdInteraction] ORDER BY [CreatedDate] ASC)
			FROM RAW_RESULTS_CTE
	),
	UNIQUE_RESULTS_CTE AS (
		SELECT * 
			FROM FILTERED_RESULTS_CTE WHERE [RN] >= @TOTAL_ABILITIES
	)
	SELECT UR_CTE.[IdEvaluationPlan]				'EvaluationPlanId',
			UR_CTE.[IdCampaign]						'CampaignId',
			UR_CTE.[InteractionType]				'InteractionmType',
			UR_CTE.[IdInteraction]					'InteractionId',
			UR_CTE.[IdAgent]						'AgentId',
			UR_CTE.[InteractionDateIni]				'StartDate',
			UR_CTE.[InteractionDateFin]				'EndDate',
			HA.[Title]								'Ability',
			ER.[ScoreDescription]					'AbilityResult'
		FROM UNIQUE_RESULTS_CTE UR_CTE
		INNER JOIN [dbo].[EvaluationResult] ER (NOLOCK)
			ON ER.[Instance] = UR_CTE.[Instance] 
				AND ER.[IdEvaluationPlan] = UR_CTE.[IdEvaluationPlan]
				AND ER.[IdInteraction] =  UR_CTE.[IdInteraction]
		INNER JOIN [dbo].[HistoricAbility] HA (NOLOCK)
			ON HA.[VCC] = UR_CTE.[Instance] 
				AND HA.[EvaluationPlanId] = UR_CTE.[IdEvaluationPlan]
				AND HA.[ID] = ER.[IdAbility]
	
	/*
	SELECT STUFF(
				(
					SELECT DISTINCT ',' + IdInteraction
						FROM UNIQUE_RESULTS_CTE
					FOR XML PATH(''), TYPE
				).value('.', 'NVARCHAR(MAX)'), 
				1, 
				1, 
				''
	)						'InteractionIds'
	*/
	/*
	EXEC [dbo].[GetEvaluationResultsByCriteria] 
	@EvaluationPlanId = 'plan_transferencia_2202_bbva', 
	@AgentIds = 'xp65048@gss.bbva.com,xp65024@gss.bbva.com,maria.cubas.cruz.contractor@bbva.com', 
	@OKAbilities = 'Amabilidad_empatia,Despedida_query', 
	@KOAbilities = 'Bienvenida'
	*/

	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[SaveEvaluationAttachedSignature]...';


GO
CREATE PROCEDURE [dbo].[SaveEvaluationAttachedSignature] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationFormatId VARCHAR(50) = NULL,
	@Description VARCHAR(100) = NULL,
	@Order Int = NULL,
	@CreatedByUserId VARCHAR(50) = NULL,
	@LastModifiedByUserId VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	UPDATE [EvaluationFormatAttachedSignature]
		SET [Order] = @Order,
			[LastModifiedDate] = GETUTCDATE(),
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[TimeStamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [EvaluationFormatId] = @EvaluationFormatId
			AND [Order] = @Order

    IF @@ROWCOUNT = 0
		INSERT INTO [EvaluationFormatAttachedSignature] (
			[VCC], 
			[EvaluationFormatId],
			[Description],
			[Order], 
			[CreatedDate],
			[CreatedByUserId],
			[TimeStamp]
		)
		VALUES (
			@VCC, 
			@EvaluationFormatId,
			@Description, 
			@Order,
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE()
		)

	SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
PRINT N'Actualización completada.';


GO
