PRINT N'Iniciando recompilación de la tabla [dbo].[Ability]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_Ability] (
    [Instance]             VARCHAR (50)   NOT NULL,
    [ID]                   VARCHAR (50)   NOT NULL,
    [Title]                VARCHAR (100)  NOT NULL,
    [Detail]               VARCHAR (500)  NOT NULL,
    [Type]                 VARCHAR (50)   NULL,
    [CalificationType]     VARCHAR (50)   NULL,
    [Binary]               BIT            NULL,
    [NotApply]             BIT            NULL,
    [Distribute]           BIT            NULL,
    [AcceptComments]       BIT            NULL,
    [CreatedDate]          DATETIME       NULL,
    [CreatedByUserId]      VARCHAR (50)   NULL,
    [LastModifiedDate]     DATETIME       NULL,
    [LastModifiedByUserId] VARCHAR (50)   NULL,
    [TimeStamp]            DATETIME       NULL,
    [Enabled]              BIT            NULL,
    [AnalysisType]         VARCHAR (25)   NULL,
    [Query]                VARCHAR (1000) NULL,
    [QueryName]            VARCHAR (50)   NULL,
    [Language]             VARCHAR (50)   NULL,
    [IsNegative]           BIT            NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_Ability1] PRIMARY KEY CLUSTERED ([Instance] ASC, [ID] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[Ability])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_Ability] ([Instance], [ID], [Title], [Detail], [Type], [Binary], [NotApply], [Distribute], [AcceptComments], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp], [Enabled], [AnalysisType], [Query], [QueryName], [Language], [IsNegative])
        SELECT   [Instance],
                 [ID],
                 [Title],
                 [Detail],
                 [Type],
                 [Binary],
                 [NotApply],
                 [Distribute],
                 [AcceptComments],
                 [CreatedDate],
                 [CreatedByUserId],
                 [LastModifiedDate],
                 [LastModifiedByUserId],
                 [TimeStamp],
                 [Enabled],
                 [AnalysisType],
                 [Query],
                 [QueryName],
                 [Language],
                 [IsNegative]
        FROM     [dbo].[Ability]
        ORDER BY [Instance] ASC, [ID] ASC;
    END

DROP TABLE [dbo].[Ability];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_Ability]', N'Ability';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_Ability1]', N'PK_Ability', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Creando [dbo].[HistoricScore]...';


GO
CREATE TABLE [dbo].[HistoricScore] (
    [VCC]              VARCHAR (50)   NOT NULL,
    [ID]               VARCHAR (50)   NOT NULL,
    [IdAbility]        VARCHAR (50)   NULL,
    [Description]      VARCHAR (100)  NULL,
    [Value]            NUMERIC (5, 1) NULL,
    [EvaluationPlanId] VARCHAR (50)   NOT NULL
);


GO
PRINT N'Modificando [dbo].[GetEvaluationResults]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluationResults] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@AuditorId VARCHAR(50) = NULL
) 
AS
BEGIN
	SET NOCOUNT ON

	-- SP PARA SOLICITAR LOS RESULTADOS DE LA EVALUACION DE UNA INTERACCION POR VCC, PLAN Y AUDITOR 
	SELECT ER.[IdAbility]							'idAbility',
			A.[Type]								'abilityType',
			ER.[Qualification]						'qualification',
			ER.[ScoreDescription]					'scoreDescription',
			ER.[Comment]                            'comments',
			ER.[Conditional]                        'conditional',
			ER.[EvaluationDate]						'evaluationDate',
			ER.[AbilityOrder]						'abilityOrder',
			ER.[LastModifiedByUserId]				'lastModifiedByUserId',
			ER.[LastModifiedDate]					'lastModifiedDate'
		FROM [dbo].[EvaluationResult] ER (NOLOCK)
		LEFT JOIN [dbo].[Ability] A (NOLOCK) 
			ON A.[Instance] = ER.[Instance]
				AND A.[ID] = ER.[IdAbility]
		WHERE ER.[Instance] = @VCC 
			AND ER.[IdEvaluationPlan] = @EvaluationPlanId
			AND ER.[IdInteraction] = @InteractionId
			AND ER.[IdAuditor] = @AuditorId
		ORDER BY ER.[AbilityOrder] ASC
		
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveHistoricEvaluationPlanData]...';


GO

ALTER PROCEDURE [dbo].[SaveHistoricEvaluationPlanData] (
	@VCC VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50)=NULL,
	@FormatId VARCHAR(100) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	
	     INSERT INTO [dbo].[HistoricEvaluationFormat] 
            SELECT 
            EF.[Instance],
            EF.[ID],
            EF.[Description],
            EF.[type],
            EF.[EnvironmentType],
            EF.[MinAutomaticQualification],
            EF.[MinQualificationAcceptable],
            EF.[ManagementFormURL],
            EF.[Enabled],
            EF.[templateId],
			@EvaluationPlanId
            FROM [dbo].[EvaluationFormat] EF (NOLOCK) 
            WHERE [ID] = @FormatId AND [Instance] = @VCC


		 
			INSERT INTO [dbo].[HistoricAbilityEvaluationFormat]
			SELECT DISTINCT A.[Instance],
							A.[ID] ,
							A.[IdEvaluationFormat],
							A.[IdAbility],
							A.[IdGroup],
							A.[IdSubGroup],
							A.[Penalizes],
							A.[Score],
							A.[Order],
							A.[Conditional],
							@EvaluationPlanId
				FROM  [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
					ON EF.[Instance] = A.[Instance] 
						AND EF.[ID] = A.[IdEvaluationFormat]
				WHERE EF.[ID] = @FormatId AND EF.[Instance] = @VCC


			INSERT INTO [dbo].[HistoricEvaluationFormatCustomField]
			SELECT 
			ECF.[VCC],
			ECF.[ID],
			ECF.[EvaluationFormatId],
			ECF.[CustomFieldId],
			ECF.[Order],
			@EvaluationPlanId
			FROM [dbo].[EvaluationFormatCustomField] ECF (NOLOCK)
			JOIN [dbo].[EvaluationFormat] EF (NOLOCK) 
			ON ECF.[VCC] = EF.[Instance] AND ECF.[EvaluationFormatId] = EF.[ID]
			WHERE EF.[ID] = @FormatId AND EF.[Instance] = @VCC
			GROUP BY
			ECF.[VCC],
			ECF.[ID],
			ECF.[EvaluationFormatId],
			ECF.[CustomFieldId],
			ECF.[Order]


	    INSERT INTO [dbo].[HistoricCustomField]
		SELECT 
			 C.[VCC],
			 C.[ID],
			 C.[Description],
			 C.[Type],
			 C.[Label],
			 @EvaluationPlanId
			FROM [dbo].[CustomField] C (NOLOCK)
			JOIN [dbo].[EvaluationFormatCustomField] FC (NOLOCK)
			ON C.[VCC] = FC.[VCC] AND C.[ID] = FC.[CustomFieldId]
			WHERE FC.[EvaluationFormatId] = @FormatId AND FC.[VCC] = @VCC
			GROUP BY       
			 C.[VCC],
			 C.[ID],
			 C.[Description],
			 C.[Type],
			 C.[Label]



			INSERT INTO [dbo].[HistoricCustomFieldResult]
			SELECT
			CR.[VCC],
			CR.[ID],
			CR.[Description],
			CR.[Order],
			CR.[CustomFieldId],
			@EvaluationPlanId
			FROM [dbo].[CustomFieldResult] CR (NOLOCK)
			JOIN [dbo].[CustomField] C (NOLOCK)
			ON CR.[VCC] = C.[VCC] AND CR.[CustomFieldId] = C.[ID]
			JOIN [dbo].[EvaluationFormatCustomField] FC (NOLOCK)
			ON C.[VCC] = FC.[VCC] AND C.[ID] = FC.[CustomFieldId]
			WHERE FC.[EvaluationFormatId] = @FormatId AND FC.[VCC] = @VCC
			GROUP BY 
			CR.[VCC],
			CR.[ID],
			CR.[Description],
			CR.[Order],
			CR.[CustomFieldId]
	
	

			INSERT INTO 
			[dbo].[HistoricEvaluationFormatAttachedSignature]
			SELECT 
				AFS.[VCC],
				AFS.[Description],
				AFS.[Order],
				AFS.[EvaluationFormatId],
				@EvaluationPlanId
			FROM [dbo].[EvaluationFormatAttachedSignature] AFS (NOLOCK)
            WHERE AFS.[EvaluationFormatId] = @FormatId AND AFS.[VCC] = @VCC


	
			INSERT INTO [dbo].[HistoricCampaignEvaluationFormat]
			SELECT
				CEF.[Instance],
				CEF.[IdEvaluationFormat],
				CEF.[IdCampaign],
				@EvaluationPlanId
			FROM [dbo].[CampaignEvaluationFormat] CEF (NOLOCK) 
			WHERE CEF.[IdEvaluationFormat] = @FormatId AND CEF.[Instance] = @VCC
			GROUP BY 
				CEF.[Instance],
				CEF.[IdEvaluationFormat],
				CEF.[IdCampaign]



		        INSERT INTO [dbo].[HistoricGroup] 
				SELECT 
					G.[Instance] ,
					G.[ID],
					G.[Description] ,
					G.[Enabled],
					@EvaluationPlanId
				FROM [dbo].[Group] G (NOLOCK)
				JOIN [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				ON  A.[Instance] = G.[Instance] AND A.[IdGroup] = G.[ID]
				WHERE A.[IdEvaluationFormat] = @FormatId AND A.[Instance] = @VCC
				GROUP BY 
				G.[Instance] ,
				G.[ID],
				G.[Description] ,
				G.[Enabled] 
	



		        INSERT INTO [dbo].[HistoricSubGroup] 
				SELECT 
					G.[Instance] ,
					G.[ID],
					G.[Description] ,
					G.[Enabled],
					@EvaluationPlanId
				FROM [dbo].[SubGroup] G (NOLOCK)
				JOIN [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				ON  A.[Instance] = G.[Instance] AND A.[IdSubGroup] = G.[ID]
				WHERE A.[IdEvaluationFormat] = @FormatId AND A.[Instance] = @VCC
				GROUP BY 
				    G.[Instance] ,
					G.[ID],
					G.[Description] ,
					G.[Enabled] 



		INSERT INTO [dbo].[HistoricAbility] 
			SELECT A.[Instance],
					A.[ID],
					A.[Title],
					A.[Detail],
					A.[Type],
					A.[Binary],
					A.[NotApply],
					A.[Distribute],
					A.[AcceptComments],
					A.[Enabled],
					A.[AnalysisType],
					A.[Query],
					A.[QueryName],
					A.[Language],
					A.[IsNegative],
					@EvaluationPlanId
				FROM [dbo].[Ability] A (NOLOCK)
				JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
					ON  A.[Instance] = AEF.[Instance] 
						AND AEF.[IdAbility] = A.[ID]
				WHERE AEF.[IdEvaluationFormat] = @FormatId AND A.[Instance] = @VCC

		INSERT INTO [dbo].[HistoricScore] 
			SELECT DISTINCT S.[Instance], S.[ID], S.[IdAbility], S.[Description], S.[Value], EP.[ID]
				FROM [dbo].[EvaluationPlan] EP (NOLOCK)
				LEFT JOIN [dbo].[AbilityEvaluationFormat] AEP (NOLOCK)
					ON AEP.[Instance] = EP.[Instance]
						AND AEP.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				LEFT JOIN [dbo].[Score] S (NOLOCK)
					ON S.[Instance] = EP.[Instance]
						AND S.[IdAbility] = AEP.[IdAbility]
				WHERE EP.[ID] = @EvaluationPlanId


		INSERT INTO [dbo].[HistoricAbilityQuery]
		SELECT 
			AQ.[ID],
			AQ.[VCC],
			AQ.[AbilityId],
			AQ.[QueryId],
			AQ.[QueryContent],
			AQ.[AcceptancePercentage],
			AQ.[Order],
			@EvaluationPlanId
		FROM [dbo].[AbilityQuery] AQ (NOLOCK)
		JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
		ON  AQ.[VCC] = AEF.[Instance] AND AEF.[IdAbility] = AQ.[AbilityId]
		WHERE AEF.[IdEvaluationFormat] = @FormatId AND AQ.[VCC] = @VCC
		GROUP BY 
		    AQ.[ID],
			AQ.[VCC],
			AQ.[AbilityId],
			AQ.[QueryId],
			AQ.[QueryContent],
			AQ.[AcceptancePercentage],
			AQ.[Order]


			   INSERT INTO [dbo].[HistoricAbilityQueryEntity]
						    SELECT 
							AQE.[VCC],
							AQE.[AbilityQueryId],
							AQE.[EntityId],
							AQE.[EntityName],
							AQE.[AcceptancePercentage],
							AQE.[Order],
							@EvaluationPlanId
							FROM [dbo].[AbilityQueryEntity] AQE (NOLOCK)
							JOIN [dbo].[AbilityQuery] AQ (NOLOCK)
							ON AQ.[VCC] = AQE.[VCC] AND AQE.[AbilityQueryId] = AQ.[ID]
							JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
							ON  AQ.[VCC] = AEF.[Instance] AND AEF.[IdAbility] = AQ.[AbilityId]
							WHERE AQ.[VCC] = @VCC AND AEF.[IdEvaluationFormat] = @FormatId
							GROUP BY 
							AQE.[VCC],
							AQE.[AbilityQueryId],
							AQE.[EntityId],
							AQE.[EntityName],
							AQE.[AcceptancePercentage],
							AQE.[Order]
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetAbilityEvaluationFormats]...';


GO


ALTER PROCEDURE [dbo].[GetAbilityEvaluationFormats] (
	@Instance           Varchar(50) = NULL, 
	@IdEvaluationFormat Varchar(50) = NULL,
	@EvaluationPlanId   VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	DECLARE @QUERY VARCHAR(MAX) = ''

	SET @QUERY += '	SELECT DISTINCT
					AEF.[ID]							''id'',
					AEF.[IdEvaluationFormat]		''idEvaluationFormat'',
					AEF.[IdAbility]					''idAbility'',
					A.[Title]						''titleAbility'',
					A.[Detail]						''detailAbility'',
					A.[Type]						''abilityType'',
					A.[AnalysisType]				''abilityAnalysisType'',
					AEF.[IdGroup]					''idGroup'',
					G.[Description]                 ''descriptionGroup'',
					AEF.[IdSubGroup]				''idSubGroup'',
					SG.[Description]                ''descriptionSubGroup'',
					AEF.[Penalizes]					''penalizes'',
					AEF.[Score]						''score'',
					AEF.[Order]						''order'',
					A.[NotApply]					''acceptNotApplies'',
					A.[Distribute]					''distribute'',
					A.[AcceptComments]				''acceptComments'',
					A.[Detail]						''descriptionAbility'',
					AEF.[Conditional]				''conditional'',
					A.[Query]						''abilityQuery'',
					A.QueryName						''query'',
					A.[IsNegative]                  ''isNegative'''

	 IF(@EvaluationPlanId IS NOT NULL AND @EvaluationPlanId <> '')
	 BEGIN 

			SET @QUERY +='	FROM [dbo].[HistoricAbilityEvaluationFormat] AEF (NOLOCK)
				INNER JOIN [dbo].[HistoricGroup] G (NOLOCK)
					ON G.[VCC] = AEF.[VCC]
						AND G.[ID] = AEF.[IdGroup] AND G.[EvaluationPlanId] = AEF.[EvaluationPlanId]
				INNER JOIN [dbo].[HistoricSubGroup] SG (NOLOCK)
					ON SG.[VCC] = AEF.[VCC]
						AND SG.[ID] = AEF.[IdSubGroup]
						AND SG.[EvaluationPlanId] = AEF.[EvaluationPlanId]
				INNER JOIN [dbo].[HistoricAbility] A (NOLOCK)
					ON A.[VCC] = AEF.[VCC]
						AND A.[ID] = AEF.[IdAbility]
						AND A.[EvaluationPlanId] = AEF.[EvaluationPlanId]
				WHERE AEF.[VCC] = '''+@Instance+'''
					AND AEF.[IdEvaluationFormat]= '''+@IdEvaluationFormat+'''
				    AND AEF.[EvaluationPlanId] = '''+@EvaluationPlanId+'''
				ORDER BY [Order] ASC'
	
	 END
	 ELSE
	 BEGIN 

		   SET @QUERY += '	FROM [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
				INNER JOIN [dbo].[Group] G (NOLOCK)
					ON G.[Instance] = AEF.[Instance]
						AND G.[ID] = AEF.[IdGroup]
				INNER JOIN [dbo].[SubGroup] SG (NOLOCK)
					ON SG.[Instance] = AEF.[Instance]
						AND SG.[ID] = AEF.[IdSubGroup]
				INNER JOIN [dbo].[Ability] A (NOLOCK)
					ON A.[Instance] = AEF.[Instance]
						AND A.[ID] = AEF.[IdAbility]
				WHERE AEF.[Instance] = '''+ @Instance+'''
					AND AEF.[IdEvaluationFormat]= '''+@IdEvaluationFormat+'''
				ORDER BY [Order] ASC'
			
	 END

	 EXEC(@QUERY)
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetAuditorEvaluationPlanEvaluation]...';


GO
ALTER PROCEDURE [dbo].[GetAuditorEvaluationPlanEvaluation] (
	@Instance Varchar(50) = NULL,
	@AuditorId Varchar(50) = NULL,
	@EvaluationPlanId Varchar(50) = NULL,
	@InteractionId Varchar(250) = NULL,
	@InteractionType Varchar(25) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT AEP.[IdEvaluationPlan]				'evaluationPlanId', 
			EP.[Evaluation_Mode]				'evaluation_mode',
			AEP.[IdAuditor]						'auditorId', 
			IEP.[IdAgent]						'agentId',
			IEP.[AgentName]						'agentName',
			AEP.[IdInteraction]					'interactionId', 
			AEP.[Completed]						'evaluationCompleted', 
			EP.[Description]					'evaluationPlanDescription',
			EP.[IdEvaluationFormat]				'evaluationFormatId',
			AEP.[Completed]						'completed',
			AEP.[Status]						'status',
			AEP.[StatusDescription]				'statusDescription'
		FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
		INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
			ON EP.[Instance] = AEP.[Instance]
				AND EP.ID = AEP.IdEvaluationPlan
		INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
			ON IEP.[Instance] = AEP.[Instance]
				AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
				AND IEP.[IdInteraction] = AEP.[IdInteraction]
				AND IEP.[InteractionType] = AEP.[InteractionType]
				AND IEP.[IdAgent] = AEP.[IdAgent]
		WHERE AEP.[Instance] = @Instance 
			AND AEP.[IdEvaluationPlan] = @EvaluationPlanId 
			AND AEP.[IdAuditor] = @AuditorId 
			AND AEP.[IdInteraction] = @InteractionId
			AND AEP.[InteractionType] = @InteractionType;

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetBillingInteractions]...';


GO
ALTER PROCEDURE [dbo].[GetBillingInteractions] (
	@VCC					VARCHAR(50) = NULL,
	@SecondsPerRequest		DECIMAL(18, 5) = 0,
	@CharsPerPhrase			DECIMAL(18, 5) = 0,
	@Channel				VARCHAR(25) = NULL,
	@Retranscription		BIT = 0
	
)
AS
BEGIN
	
	-- SEGUN EL TIPO DE CANAL DEFINIMOS LA FUNCION
	IF @Channel = 'CALL'
	BEGIN
		-- SELECT * FROM [#InteractionsTemp] IT
		
		SELECT SUM(CASE WHEN A.[IsTranscribed] = 1 AND @Retranscription = 0 THEN 1 ELSE 0 END)									'alreadyTranscribedAudio',
				SUM(CASE WHEN A.[IsTranscribed] = 1 AND @Retranscription = 0 THEN IT.[AttentionTime] ELSE 0 END)					'alreadyTranscribedDurationTime',
				SUM(CASE WHEN (A.[IsProcess] = 1 
								AND A.[IsTranscribed] IS NULL 
								AND A.[IsCancel] IS NULL) 
							THEN 1 ELSE 0 END)															'inProcessAudio',
				SUM(CASE WHEN (A.[IsProcess] = 1 
								AND A.[IsTranscribed] IS NULL 
								AND A.[IsCancel] IS NULL) 
							THEN IT.[AttentionTime] ELSE 0 END)											'inProcessDurationTime',
				@Channel																				'interactionType',
				SUM(CASE WHEN (
					A.[IsProcess] IS NULL 
					OR
					@Retranscription = 1
					OR 
					(
						A.[IsProcess] = 1 
						AND 
						A.[IsCancel] = 1
					)
				) THEN 1 ELSE 0 END)															'notTranscribedAudio',
				SUM(CASE WHEN (
					A.[IsProcess] IS NULL 
					OR
					@Retranscription = 1
					OR (
						A.[IsProcess] = 1 
						AND 
						A.[IsCancel] = 1
					)
				) THEN IT.[AttentionTime] ELSE 0 END)													'notTranscribedDurationTime',
				SUM(CASE WHEN A.[IsTranscribed] = 1  
								AND A.[TotalPhrases] IS NOT NULL
							THEN A.[TotalPhrases] ELSE 0 END)											'totalPhrases',
				SUM(CASE WHEN (A.[IsProcess] IS NULL 
								OR (A.[IsProcess] = 1 
									AND A.[IsCancel] = 1)
								OR (A.[TotalPhrases] IS NULL)) 
							THEN (IT.[AttentionTime] / @SecondsPerRequest) ELSE 0 END)					'totalRawPhrases',
				SUM(IT.[AttentionTime] / @SecondsPerRequest)											'averageModelRequest' 
			FROM [#InteractionsTemp] IT
			LEFT JOIN [dbo].[Audio] A (NOLOCK) 
				ON A.[VCC] = IT.[VCC]
					AND A.[ID] = IT.[InteractionId]
					AND A.[Section] = IT.[Section]
					AND A.[Part] = IT.[Part] 
			WHERE IT.[VCC] = @VCC
			
	END
	ELSE
	BEGIN
		-- DECLARAMOS UNA VARIABLE PARA PARA EL TOTALDE RESULTADOS
		DECLARE @TOTAL_INTERACTIONS INT = 0

		-- SETTEAMOS EL NUMERO DE REGISTROS A LA VARIABLE DE TOTAL
		SELECT @TOTAL_INTERACTIONS = COUNT(*) FROM [#InteractionsTemp]

		IF @TOTAL_INTERACTIONS = 0 
		BEGIN
			-- SI NO EXISTEN RESULTADOS EN HD LLENAMOSUN RESULTADOS CON 0
			SELECT @Channel																					'interactionType',
					0																						'totalInteractionDetails',
					0																						'alreadyTranscribedInteraction',
					0																						'inProcessInteraction',
					0																						'notTranscribedInteraction',
					0																						'totalPhrases',
					0																						'totalRawChars',
					0																						'totalRawPhrases'
		END 
		ELSE
		BEGIN
			-- CRUZAMOS LA TABLA TEMPORAL DE INTERACCIONES ASINCRONAS CON LA TABLA LOCAL INTERACTION PARA LAS INTERACCIONES ASINCRONAS YA REGISTRADAS
			SELECT ISNULL(IT.[Channel], @Channel)															'interactionType',
					COUNT(*)																				'totalInteractionDetails',
					SUM(CASE WHEN (AI.[VCC] IS NOT NULL 
						AND AI.[IsTranscribed] = 1) THEN 1 ELSE 0 END)				'alreadyTranscribedInteraction',
					0																						'inProcessInteraction',
					SUM(CASE WHEN (AI.[VCC] IS NULL 
						OR AI.[IsTranscribed] <> 1) THEN 1 ELSE 0 END)										'notTranscribedInteraction',
					SUM(ISNULL(AI.[TotalPhrases], 0))														'totalPhrases',
					-- CUANDO TENEMOS VALIDPHRASES, YA NO CONTAMOS LAS RAWCHAR 
					SUM(
						CASE WHEN (AI.[TotalPhrases] IS NULL 
								OR AI.[TotalPhrases] = 0)
						THEN (
							ISNULL(AI.[RawChar], ISNULL(IT.[rawChar], 0))
						)
						ELSE 0 END
					)																						'totalRawChars',
					SUM(
						CASE WHEN (AI.[TotalPhrases] IS NULL 
								OR AI.[TotalPhrases] = 0)
						THEN (
							-- SI RAWCHAR ES NULL, SE DEBE VALUAR COMO MINIMO 1 FRASE(@CharsPerPhrase)
							-- CEILING(ISNULL(AI.[RawChar], ISNULL(HDI.[rawChar], @CharsPerPhrase)) * 1.00 / @CharsPerPhrase)
							CEILING(ISNULL(AI.[RawChar], ISNULL(IT.[RawChar], 0)) * 1.00 / @CharsPerPhrase)
						)
						ELSE 0 END
					)																						'totalRawPhrases' 
				FROM [#InteractionsTemp] IT
				LEFT JOIN [dbo].[AsyncInteraction] AI 
					ON IT.[VCC] = AI.[VCC]
						AND IT.[Channel] = AI.[Channel]
						AND IT.[Campaign] = AI.[Campaign]
						AND IT.[InteractionId] = AI.[ID]
						AND IT.[EndDate] = AI.[EndDate]
					--WHERE AI.[VCC] = @VCC
				GROUP BY IT.[VCC],
							IT.[Channel]

		END
	END

	-- ELIMINAMOS LA TABLA TEMPORAL
	DROP TABLE [#InteractionsTemp] 
END
GO
PRINT N'Modificando [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan]...';


GO

ALTER PROCEDURE [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan] (
	@Instance Varchar(50) = NULL,
    @EvaluationPlanId Varchar(50) = NULL,
    @InteractionId varchar(250) = NULL,
    @InteractionType varchar(50) = NULL,
    @AuditorId varchar(50) = NULL,
    @AgentId varchar(50) = NULL
)
AS
BEGIN
    SET NOCOUNT ON
	-- TODO: ESTE SP ES USADO PARA GENERAR EL PDF DE EXPORTACION, HAY QUE INTEGRARLO CON LA FUNCIONALIDAD FACTORIZADA Y DESAPARECER ESTE SP

	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA OBTENER LOS REGISTROS UNICOS QUE INSERTAREMOS EN LA TABLA EVALUATION_RESULT
	--  ORDENANDO POR SECTION Y PART Y OBTENER EL NOMBRE DEL AGENTE
	;WITH CTE AS (
		SELECT TOP 1 IEP.[Instance],
						IEP.[IdEvaluationPlan],
						IEP.[IdInteraction],
						IEP.[IdAgent],
						IEP.[AgentName]
			FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
			WHERE IEP.[Instance] = @Instance
				AND IEP.[IdEvaluationPlan] = @EvaluationPlanId
				AND IEP.[IdInteraction] = @InteractionId 
				AND IEP.[InteractionType] = @InteractionType
				AND IEP.[IdAgent] = @AgentId
	)

    SELECT DISTINCT
         EF.Id										'EvaluationFormatId'				-- Id
        ,EF.Description								'EvaluationFormatDescription'		-- Titulo del reporte
        ,ER.Instance								'Instance'							-- Subtitulo del reporte
        ,ER.IdAgent									'AgentId'							-- Agente
        ,ER.IdAgent									'AgentDescription'					-- Agente
		,C.[AgentName]								'agentName'							-- NOMBRE DEL AGENTE
        ,CONCAT(U.Firstname, ' ', U.Lastname)		'CoordinatorFullName'				-- Coordinador
        ,AEP.IdAuditor								'AuditorId'							-- Auditor
        ,CONCAT(UA.Firstname, ' ',UA.Lastname)		'AuditorDescription'				-- Auditor
		,AEP.IdAuditor
        ,ER.IdCampaign								'CampaignDescription'				-- Campana
        ,ER.IdInteraction							'InteractionId'						-- Grabacion
        ,ER.InteractionType							'InteractionType'					-- Tipo interaccion
        ,ER.InteractionDateini						'InteractionDateIni'				-- Fecha inicio de la interaccion
		,ER.[InteractionDatefin]					'InteractionDateFin'				-- Fecha fin de la interaccion
        ,ER.InteractionAddress						'Contacto'							-- Telefono
        ,ER.EvaluationDate							'EvaluationDate'					-- Fecha monitoreo
        ,AEP.Score									'TotalScore'						-- Puntaje total
        ,G.Id										'GroupId'							-- Grupo
        ,G.Description								'Group'								-- Grupo
        ,SG.Id										'SubGroupId'						-- Subgrupo
        ,SG.Description								'SubGroup'							-- Subgrupo
        ,AB.Id										'AbilityId'							-- Habilidad
        ,AB.Title									'Ability'							-- Habilidad
		,AB.[Detail]								'AbilityDetail'						-- Habilidad
        ,ER.Comment									'Observacion'						-- Observacion de la habilidad
        ,ER.MaxAbilityScore							'Puntaje'							-- Puntaje
        ,ER.ScoreDescription						'Eval'								-- Eval
        ,ER.Qualification							'Nota'								-- Nota
		,ER.[OwnScore]								'ownScore'
		,ER.[InheritedScore]						'inheritedScore'
		,ER.[AbilityInnerScore]						'abilityInnerScore'
        ,ER.NotApplies								'NotApplies'
		,AB.[Distribute]							'distribute'
        ,ER.AbilityOrder							'Order'
        ,ER.Conditional                             'conditionalSelected'
    FROM [dbo].[EvaluationResult] ER (NOLOCK)
    INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK) 
         ON (EP.[Instance] = ER.[Instance]
			AND EP.ID = ER.IdEvaluationPlan)
	INNER JOIN	[dbo].[HistoricEvaluationFormat] EF (NOLOCK)
	--LEFT JOIN [EvaluationFormat] EF (NOLOCK)
		ON (ER.Instance = EF.VCC AND EP.ID = EF.EvaluationPlanId
			AND	ER.IdEvaluationFormat = EF.ID)
	LEFT JOIN [dbo].[User] U (NOLOCK)
		ON (EP.Instance = U.VCC
			AND EP.CreatedByUserId = U.ID)
    --INNER JOIN [User] UA (NOLOCK)
	LEFT JOIN [dbo].[User] UA (NOLOCK)
		ON (ER.Instance = UA.VCC 
			AND ER.IdEvaluator = UA.ID)
    --INNER JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
	LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
		ON (ER.IdEvaluationPlan	= AEP.IdEvaluationPlan
			AND ER.IdEvaluator = AEP.IdAuditor
			AND ER.IdInteraction = AEP.IdInteraction
			AND ER.InteractionType = AEP.InteractionType
			AND ER.IdAgent = AEP.IdAgent)
    LEFT JOIN [dbo].[HistoricGroup] G (NOLOCK)
		ON (ER.Instance = G.VCC AND EP.ID = G.EvaluationPlanId
			AND ER.IdGroup = G.ID)
    LEFT JOIN [HistoricSubGroup] SG (NOLOCK)
		ON (ER.Instance = SG.VCC AND EP.ID = SG.EvaluationPlanId
			AND ER.IdSubGroup = SG.ID)
    LEFT JOIN [HistoricAbility] AB (NOLOCK)
		ON (ER.Instance = AB.VCC AND EP.ID = AB.EvaluationPlanId
			AND ER.IdAbility = AB.ID)
	LEFT JOIN CTE C (NOLOCK) -- LA TABLA AGENT NO ES DETERMINANTE POR ESO SE AGREGA POR LEFT JOIN
		ON C.[Instance] = ER.[Instance]
			AND C.[IdInteraction] = ER.IdInteraction
			AND C.[IdAgent] = ER.[IdAgent]
    WHERE ER.Instance = @Instance
		AND ER.IdEvaluationPlan	= @EvaluationPlanId
		AND ER.IdInteraction = @InteractionId
		AND ER.InteractionType = @InteractionType
		--AND ER.IdEvaluator = @AuditorId
		AND ER.[IdAuditor] = @AuditorId
		AND ER.IdAgent = @AgentId
		AND AEP.[StatusDescription] NOT IN ('INVALID')
    ORDER BY ER.AbilityOrder ASC
	
    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetIntents]...';


GO
ALTER PROCEDURE [dbo].[GetIntents] (
	@VCC Varchar(50) = NULL, 
	@AppId VARCHAR(100) = NULL,
	@SearchCriteria Varchar(50) = NULL, 
	@SearchExpression Varchar(50) = NULL,
	@Intents NVARCHAR(MAX)
	)
AS
BEGIN
	
	DECLARE @COGNITIVE_ENGINE VARCHAR(5) = NULL
	DECLARE @SQL NVARCHAR(MAX)

	-- DETERMINAMOS EL MOTOR COGNITIVO DEL VCC
	SELECT @COGNITIVE_ENGINE = N.[CognitiveEngine]
		FROM [dbo].[NLU] N (NOLOCK)
		WHERE N.[VCC] = @VCC
			AND N.[AppId] = @AppId
	
	SET @SQL = '
	SET NOCOUNT ON
	SELECT [Name]						    ''name'',
	        [AppId]                         ''appId'',
			[IntentId]						''intentId'',
			[Color]							''color'',
			[CreatedDate]					''createdDate'',
			[CreatedByUserId]				''createdByUserId'',
			[LastModifiedDate]				''lastModifiedDate'',
			[LastModifiedByUserId]			''lastModifiedByUserId'',
			[Status]                        ''status'',
			[StatusCode]                    ''statusCode'',
			IIF(
				EXISTS(
					SELECT 1 
						FROM [dbo].[Utterance] 
						WHERE [VCC] = [dbo].[Intent].[VCC] 
							and [AppId] = [dbo].[Intent].[AppId] 
							and [IntentId] = [dbo].[Intent].[IntentId]), 
				1, 
				0
			)								''hasUtterances''
		FROM [dbo].[Intent] (NOLOCK)
		WHERE [VCC] = ''' + @VCC + '''
			AND [AppId] = ''' + @AppId + ''' '

	-- PARA NLUS DE LUIS, FILTRAMOS SEGUN EL INPUT
	IF @COGNITIVE_ENGINE = 'LUIS'
	BEGIN
		SET @SQL +=	'
			AND [IntentId] IN (''' + @Intents + ''') '
	END

	IF @SearchCriteria IS NOT NULL AND @SearchExpression IS NOT NULL
	BEGIN
		SET @SQL +=	'
			AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END '
	END

	SET @SQL +=	'
		ORDER BY [LastModifiedDate] ASC, [Name] DESC '

	SET @SQL += ' 
	SET NOCOUNT OFF'

	EXEC(@SQL)
END
GO
PRINT N'Creando [dbo].[GetEvaluationPlanAbilities]...';


GO

CREATE PROCEDURE [dbo].[GetEvaluationPlanAbilities] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT DISTINCT
	        HA.ID								'id',
			HA.Title							'title',
			HA.Detail							'detail',
			HA.[Type]							'type',
			HA.[AnalysisType]					'analysisType',
			HA.[Binary]							'binary',
			HA.[NotApply]						'acceptNotApply',
			HA.[AcceptComments]					'acceptComments',
			HA.[Distribute]						'distributes',
			HA.[Enabled]						'enabled',
			HA.[Query]							'query',
			HA.[Queryname]						'queryName',
			HA.[IsNegative]						'isNegative', 
			N.[Culture]							'culture'
		FROM [dbo].[HistoricAbility] HA (NOLOCK)
		LEFT JOIN [dbo].[NLU] N (NOLOCK)
			ON N.[VCC] = HA.[VCC]
				AND N.[Name] = SUBSTRING(HA.[Query], 0, CHARINDEX('|', HA.[Query]))
		WHERE HA.[VCC] = @VCC
			AND HA.[EvaluationPlanId] = @EvaluationPlanId
		ORDER BY HA.[Title]
		
	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[GetEvaluationPlanAbilitiesQueries]...';


GO
CREATE PROCEDURE [dbo].[GetEvaluationPlanAbilitiesQueries] (
	@VCC              VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50) = NULL
) 
AS
BEGIN
	SET NOCOUNT ON
    
    SELECT DISTINCT HAQ.[ID]											'id',
					HAQ.[AbilityId]										'abilityId',
					HAQ.[QueryId]										'queryId',
					HAQ.[QueryContent]									'queryContent',
					HAQ.[AcceptancePercentage]							'acceptancePercentage',
					ISNULL(HAQ.[AcceptancePercentage], 0) * 100			'acceptanceInteger',
					HAQ.[Order]										    'order' 
		FROM [dbo].[HistoricAbilityQuery] HAQ (NOLOCK) 
		WHERE HAQ.[VCC] = @VCC
			AND HAQ.[EvaluationPlanId] = @EvaluationPlanId
		ORDER BY HAQ.[Order] ASC

	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[GetEvaluationPlanAbilitiesQueriesEntities]...';


GO
CREATE PROCEDURE [dbo].[GetEvaluationPlanAbilitiesQueriesEntities] (
	@VCC              VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50) = NULL
) 
AS
BEGIN
	SET NOCOUNT ON

	SELECT DISTINCT HAQE.[AbilityQueryId]								'abilityQueryId',
					HAQE.[EntityId]										'entityId',
					HAQE.[EntityName]									'entityName',
					HAQE.[AcceptancePercentage]						    'acceptancePercentage',
					ISNULL(HAQE.[AcceptancePercentage], 0) * 100		'acceptanceInteger',
					HAQE.[Order]										'order'
		FROM [dbo].[HistoricAbilityQueryEntity] HAQE (NOLOCK) 
		WHERE HAQE.[VCC] = @VCC
			AND HAQE.[EvaluationPlanId] = @EvaluationPlanId
		ORDER BY HAQE.[Order] ASC

	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[GetEvaluationPlanGroups]...';


GO
CREATE PROCEDURE [dbo].[GetEvaluationPlanGroups] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT HG.[ID]							'id',
			HG.[Description]				'description'
		FROM [HistoricGroup] HG (NOLOCK)
		WHERE HG.[VCC] = @VCC
			AND HG.[EvaluationPlanId] = @EvaluationPlanId
		ORDER BY HG.[Description] ASC

	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[GetEvaluationPlanScores]...';


GO

Create PROCEDURE [dbo].[GetEvaluationPlanScores] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT HS.[ID]								'id',
			HS.[IdAbility]						'idAbility',
			HS.[Description]					'description',
			HS.[Value]				            'value'
		FROM [HistoricScore] HS (NOLOCK)
		WHERE [VCC] = @VCC
			AND [EvaluationPlanId] = @EvaluationPlanId
		ORDER BY Value DESC

	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[GetEvaluationPlanSubGroups]...';


GO
CREATE PROCEDURE [dbo].[GetEvaluationPlanSubGroups] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT HSG.[ID]							'id',
			HSG.[Description]				'description'
		FROM [HistoricSubGroup] HSG (NOLOCK)
		WHERE HSG.[VCC] = @VCC
			AND HSG.[EvaluationPlanId] = @EvaluationPlanId
		ORDER BY HSG.[Description] ASC

	SET NOCOUNT OFF
END
GO
PRINT N'Actualizando [dbo].[DeleteAbility]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteAbility]';


GO
PRINT N'Actualizando [dbo].[GetAbility]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAbility]';


GO
PRINT N'Actualizando [dbo].[GetAbilityDetail]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAbilityDetail]';


GO
PRINT N'Actualizando [dbo].[GetAbilitys]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAbilitys]';


GO
PRINT N'Actualizando [dbo].[GetAbilityTitle]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAbilityTitle]';


GO
PRINT N'Actualizando [dbo].[GetAverageGroupRating]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAverageGroupRating]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationFormats]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationFormats]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationPlanAbilityGenericQueryTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanAbilityGenericQueryTask]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationPlanAbilityTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanAbilityTask]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationPlanCognitiveInteractionTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanCognitiveInteractionTask]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationPlanCognitiveTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanCognitiveTask]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationResultsByCriteria]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationResultsByCriteria]';


GO
PRINT N'Actualizando [dbo].[GetGenericQueryUsage]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetGenericQueryUsage]';


GO
PRINT N'Actualizando [dbo].[GetReportByDetailAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetReportByDetailAgent]';


GO
PRINT N'Actualizando [dbo].[GetReportBySummaryAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetReportBySummaryAgent]';


GO
PRINT N'Actualizando [dbo].[GetUniqueNLUByIntents]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetUniqueNLUByIntents]';


GO
PRINT N'Actualizando [dbo].[ReportAuditsByAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportAuditsByAgent]';


GO
PRINT N'Actualizando [dbo].[ReportBySummaryFormat]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportBySummaryFormat]';


GO
PRINT N'Actualizando [dbo].[SaveAbility]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveAbility]';


GO
PRINT N'Actualizando [dbo].[SaveEvaluationBaseResult]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationBaseResult]';


GO
PRINT N'Actualizando [dbo].[BulkProgress]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkProgress]';


GO
PRINT N'Actualizando [dbo].[SaveEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationPlan]';


GO
PRINT N'Actualizando [dbo].[BulkAbilityCognitive]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkAbilityCognitive]';


GO
PRINT N'Actualizando [dbo].[BulkEvaluationPlanAbility]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkEvaluationPlanAbility]';


GO
PRINT N'Actualización completada.';


GO
